@@ -58,16 +58,8 @@ NS_ASSUME_NONNULL_BEGIN
 
     PyObjC_BEGIN_WITH_GIL
 
-        /* XXX: This is different from other proxies
-         *      to make it easier to hit a race in
-         *      proxy-registry.m for testing.
-         *
-         *      With the current implementation of
-         *      proxy-registry (using weak refs) either
-         *      order works correctly.
-         */
         PyObjC_UnregisterObjCProxy(value, self);
-        Py_XDECREF(value);
+        Py_CLEAR(value);
 
     PyObjC_END_WITH_GIL
 
@@ -362,7 +354,8 @@ NS_ASSUME_NONNULL_BEGIN
     }
 
     PyObjC_BEGIN_WITH_GIL
-        if (PyTuple_CheckExact(value) && (NSUInteger)PyTuple_Size(value) == count) { // LCOV_BR_EXCL_LINE
+        if (PyTuple_CheckExact(value) // LCOV_BR_EXCL_LINE
+            && (NSUInteger)PyTuple_Size(value) == count) {
             for (i = 0; i < count; i++) {
                 PyObject* v;
 
@@ -443,7 +436,7 @@ NS_ASSUME_NONNULL_BEGIN
         code = [coder decodeInt32ForKey:@"pytype"];
 
     } else {
-        #if  MAC_OS_X_VERSION_MIN_REQUIRED < MAC_OS_X_VERSION_10_13 && PyObjC_BUILD_RELEASE >= 1013
+#if MAC_OS_X_VERSION_MIN_REQUIRED < MAC_OS_X_VERSION_10_13 && PyObjC_BUILD_RELEASE >= 1013
         /* Old deployment target, modern SDK */
         if (@available(macOS 10.13, *)) {
             [coder decodeValueOfObjCType:@encode(int) at:&code size:sizeof(code)];
@@ -458,7 +451,6 @@ NS_ASSUME_NONNULL_BEGIN
         /* Deployment target is ancient and SDK is old */
         [coder decodeValueOfObjCType:@encode(int) at:&code];
 #endif
-
     }
 
     switch (code) { // LCOV_BR_EXCL_LINE
@@ -538,7 +530,7 @@ NS_ASSUME_NONNULL_BEGIN
 
         } else {
             int isize;
-#if  MAC_OS_X_VERSION_MIN_REQUIRED < MAC_OS_X_VERSION_10_13 && PyObjC_BUILD_RELEASE >= 1013
+#if MAC_OS_X_VERSION_MIN_REQUIRED < MAC_OS_X_VERSION_10_13 && PyObjC_BUILD_RELEASE >= 1013
             /* Old deployment target, modern SDK */
             if (@available(macOS 10.13, *)) {
                 [coder decodeValueOfObjCType:@encode(int) at:&isize size:sizeof(isize)];
@@ -577,10 +569,12 @@ NS_ASSUME_NONNULL_BEGIN
         if ([coder allowsKeyedCoding]) {
             size = [coder decodeInt64ForKey:@"pylength"];
         } else {
-#if  MAC_OS_X_VERSION_MIN_REQUIRED < MAC_OS_X_VERSION_10_13 && PyObjC_BUILD_RELEASE >= 1013
+#if MAC_OS_X_VERSION_MIN_REQUIRED < MAC_OS_X_VERSION_10_13 && PyObjC_BUILD_RELEASE >= 1013
             /* Old deployment target, modern SDK */
             if (@available(macOS 10.13, *)) {
-                [coder decodeValueOfObjCType:@encode(long long) at:&size size:sizeof(size)];
+                [coder decodeValueOfObjCType:@encode(long long)
+                                          at:&size
+                                        size:sizeof(size)];
             } else {
                 CLANG_SUPPRESS
                 [coder decodeValueOfObjCType:@encode(long long) at:&size];
@@ -592,7 +586,6 @@ NS_ASSUME_NONNULL_BEGIN
             /* Deployment target is ancient and SDK is old */
             [coder decodeValueOfObjCType:@encode(long long) at:&size];
 #endif
-
         }
 
         PyObjC_BEGIN_WITH_GIL
@@ -647,7 +640,6 @@ NS_ASSUME_NONNULL_BEGIN
     return result;
 }
 
-
 - (id)mutableCopyWithZone:(NSZone* _Nullable)zone
 {
     NSObject* result;
