@@ -51,7 +51,7 @@ PyObjC_FINAL_CLASS @interface OC_PythonDictionaryEnumerator : NSEnumerator {
 
 - (id _Nullable)nextObject
 {
-    id        key   = nil;
+    id        key = nil;
     int       rv;
     PyObject* pykey = NULL;
 
@@ -162,7 +162,7 @@ PyObjC_FINAL_CLASS @interface OC_PythonDictionaryEnumerator : NSEnumerator {
 {
     Py_ssize_t result;
     if (value == NULL) { // LCOV_BR_EXCL_LINE
-        return 0; // LCOV_EXCL_LINE
+        return 0;        // LCOV_EXCL_LINE
     }
 
     PyObjC_BEGIN_WITH_GIL
@@ -190,7 +190,7 @@ PyObjC_FINAL_CLASS @interface OC_PythonDictionaryEnumerator : NSEnumerator {
     id        result;
 
     if (value == NULL) { // LCOV_BR_EXCL_LINE
-        return nil; // LCOV_EXCL_LINE
+        return nil;      // LCOV_EXCL_LINE
     }
 
     PyObjC_BEGIN_WITH_GIL
@@ -209,7 +209,7 @@ PyObjC_FINAL_CLASS @interface OC_PythonDictionaryEnumerator : NSEnumerator {
             int r = PyDict_GetItemRef(value, k, &v);
             switch (r) {
             case -1:
-                PyObjC_GIL_FORWARD_EXC();        // LCOV_EXCL_LINE
+                PyObjC_GIL_FORWARD_EXC(); // LCOV_EXCL_LINE
             case 0:
                 PyObjC_GIL_RETURN(nil);
             case 1:
@@ -342,10 +342,16 @@ PyObjC_FINAL_CLASS @interface OC_PythonDictionaryEnumerator : NSEnumerator {
 
 - (NSEnumerator*)keyEnumerator
 {
-    if (value && PyDict_CheckExact(value)) {
+    if (value == NULL) { // LCOV_BR_EXCL_LINE
+        /* Value could be NULL during ``initWithCoder:``, but AFAIK it
+         * is not possible to invoke arbitrary methods in that state.
+         */
+        return nil; // LCOV_EXCL_LINE
+    } else if (PyDict_CheckExact(value)) {
         return [OC_PythonDictionaryEnumerator enumeratorWithWrappedDictionary:self];
 
     } else {
+        NSEnumerator* result = nil;
         PyObjC_BEGIN_WITH_GIL
             PyObject* args[2] = {NULL, value};
 
@@ -361,10 +367,10 @@ PyObjC_FINAL_CLASS @interface OC_PythonDictionaryEnumerator : NSEnumerator {
                 PyObjC_GIL_FORWARD_EXC();
             } // LCOV_EXCL_LINE
 
-            NSEnumerator* result = [OC_PythonEnumerator enumeratorWithPythonObject:iter];
-            PyObjC_GIL_RETURN(result);
+            result = [OC_PythonEnumerator enumeratorWithPythonObject:iter];
 
         PyObjC_END_WITH_GIL
+        return result;
     }
 }
 
@@ -445,8 +451,13 @@ PyObjC_FINAL_CLASS @interface OC_PythonDictionaryEnumerator : NSEnumerator {
     PyObjC_BEGIN_WITH_GIL
         PyObject* v = id_to_python(other);
 
-        if (v != NULL) {
-            SET_FIELD(value, v);
+        /* 'other' is a serialized python mapping value
+         * (not a 'real' Cocoa instance). Those can
+         * always be converted back into the corresponding
+         * Python value.
+         */
+        if (v != NULL) {         // LCOV_BR_EXCL_LINE
+            SET_FIELD(value, v); // LCOV_EXCL_LINE
         }
     PyObjC_END_WITH_GIL
 }
@@ -457,7 +468,7 @@ PyObjC_FINAL_CLASS @interface OC_PythonDictionaryEnumerator : NSEnumerator {
     if ([coder allowsKeyedCoding]) {
         code = [coder decodeInt32ForKey:@"pytype"];
     } else {
-#if  MAC_OS_X_VERSION_MIN_REQUIRED < MAC_OS_X_VERSION_10_13 && PyObjC_BUILD_RELEASE >= 1013
+#if MAC_OS_X_VERSION_MIN_REQUIRED < MAC_OS_X_VERSION_10_13 && PyObjC_BUILD_RELEASE >= 1013
         /* Old deployment target, modern SDK */
         if (@available(macOS 10.13, *)) {
             [coder decodeValueOfObjCType:@encode(int) at:&code size:sizeof(code)];
@@ -472,7 +483,6 @@ PyObjC_FINAL_CLASS @interface OC_PythonDictionaryEnumerator : NSEnumerator {
         /* Deployment target is ancient and SDK is old */
         [coder decodeValueOfObjCType:@encode(int) at:&code];
 #endif
-
     }
 
     switch (code) { // LCOV_BR_EXCL_LINE
@@ -515,7 +525,7 @@ PyObjC_FINAL_CLASS @interface OC_PythonDictionaryEnumerator : NSEnumerator {
 
 - (Class)classForCoder
 {
-    if (value && PyDict_CheckExact(value)) {
+    if (value && PyDict_CheckExact(value)) { // LCOV_BR_EXCL_LINE
         return [NSMutableDictionary class];
     } else {
         return [OC_PythonDictionary class];
