@@ -10,10 +10,6 @@
 
 #include "pyobjc.h"
 
-/* XXX: Are these includes still needed */
-#include "compile.h" /* From Python */
-#include <dlfcn.h>
-
 #include <stdarg.h>
 
 #import <Foundation/NSDictionary.h>
@@ -36,9 +32,9 @@ NS_ASSUME_NONNULL_BEGIN
 
 - (id _Nullable)initWithPyObject:(PyObject*)obj
 {
-    // XXX: Fix callers to do the registration for us.
     SET_FIELD_INCREF(pyObject, obj);
 
+    // XXX: Fix callers to do the registration for us.
     id actual = PyObjC_RegisterObjCProxy(obj, self);
     [self release];
     self = actual;
@@ -108,26 +104,24 @@ NS_ASSUME_NONNULL_BEGIN
     if (pyObject == NULL)           // LCOV_BR_EXCL_LINE
         return @"no python object"; // LCOV_EXCL_LINE
 
+    NSString* result = nil;
     PyObjC_BEGIN_WITH_GIL
 
         repr = PyObject_Repr(pyObject);
 
-        if (repr) {
-            int       err;
-            NSString* result;
+        if (!repr) {
+            PyObjC_GIL_FORWARD_EXC();
+        } // LCOV_EXCL_LINE
 
-            err = depythonify_python_object(repr, &result);
-            Py_DECREF(repr);
-            if (err == -1) {
-                PyObjC_GIL_FORWARD_EXC();
-            } // LCOV_EXCL_LINE
-
-            PyObjC_GIL_RETURN(result);
-        }
-        PyObjC_GIL_FORWARD_EXC();
+        int err = depythonify_python_object(repr, &result);
+        Py_DECREF(repr);
+        if (err == -1) {
+            PyObjC_GIL_FORWARD_EXC();
+        } // LCOV_EXCL_LINE
 
     PyObjC_END_WITH_GIL
-} // LCOV_EXCL_LINE
+    return result;
+}
 
 - (void)doesNotRecognizeSelector:(SEL)aSelector
 {
@@ -146,7 +140,7 @@ check_argcount(PyObject* pymethod, Py_ssize_t argcount)
     if (PyObjC_is_pyfunction(pymethod)) {
         func_code = (PyCodeObject*)PyObjC_get_code(pymethod);
         if (func_code == NULL) { // LCOV_BR_EXCL_LINE
-            return -1; // LCOV_EXCL_LINE
+            return -1;           // LCOV_EXCL_LINE
         }
         if (argcount == func_code->co_argcount) {
             Py_DECREF(func_code);
@@ -157,7 +151,7 @@ check_argcount(PyObject* pymethod, Py_ssize_t argcount)
     } else if (PyObjC_is_pymethod(pymethod)) {
         func_code = PyObjC_get_code(pymethod);
         if (func_code == NULL) { // LCOV_BR_EXCL_LINE
-            return -1; // LCOV_EXCL_LINE
+            return -1;           // LCOV_EXCL_LINE
         }
         if (argcount == func_code->co_argcount - 1) {
             Py_DECREF(func_code);
@@ -195,8 +189,7 @@ static PyObject* _Nullable get_method_for_selector(PyObject* obj, SEL aSelector)
         }
     }
 
-    PyObject* py_meth_name =
-        PyObjC_SELToPythonName(aSelector);
+    PyObject* py_meth_name = PyObjC_SELToPythonName(aSelector);
     if (py_meth_name == NULL) { // LCOV_BR_EXCL_LINE
         /* Can only fail due to memory errors */
         return NULL; // LCOV_EXCL_LINE
@@ -228,18 +221,20 @@ static PyObject* _Nullable get_method_for_selector(PyObject* obj, SEL aSelector)
         return YES;
     }
 
+    BOOL rv;
     PyObjC_BEGIN_WITH_GIL
         m = get_method_for_selector(pyObject, aSelector);
 
         if (m) {
             Py_DECREF(m);
-            PyObjC_GIL_RETURN(YES);
+            rv = YES;
         } else { // LCOV_EXCL_LINE
             PyErr_Clear();
-            PyObjC_GIL_RETURN(NO);
+            rv = NO;
         }
 
     PyObjC_END_WITH_GIL
+    return rv;
 }
 
 + (NSMethodSignature* _Nullable)methodSignatureForSelector:(SEL)sel
@@ -498,10 +493,6 @@ static PyObject* _Nullable get_method_for_selector(PyObject* obj, SEL aSelector)
 
         retbuffer = alloca(retsize);
 
-        /* XXX: Convert this to vectorcall, needs with some
-         * luck this can be done without creating a bound
-         * method.
-         */
         pymethod = get_method_for_selector(pyObject, aSelector);
 
         if (!pymethod) {
@@ -512,7 +503,7 @@ static PyObject* _Nullable get_method_for_selector(PyObject* obj, SEL aSelector)
         }
 
         @try {
-            argcount = [msign numberOfArguments];
+            argcount = [msign numberOfArguments]; // LCOV_BR_EXCL_LINE
 
             // LCOV_EXCL_START
         } @catch (NSObject* exc) {
@@ -535,7 +526,7 @@ static PyObject* _Nullable get_method_for_selector(PyObject* obj, SEL aSelector)
             PyObject*   pyarg;
 
             @try {
-                argtype = [msign getArgumentTypeAtIndex:i];
+                argtype = [msign getArgumentTypeAtIndex:i]; // LCOV_BR_EXCL_LINE
                 // LCOV_EXCL_START
             } @catch (NSObject* exc) {
                 PyObjC_LEAVE_GIL;
@@ -558,7 +549,7 @@ static PyObject* _Nullable get_method_for_selector(PyObject* obj, SEL aSelector)
 
             Py_BEGIN_ALLOW_THREADS
                 @try {
-                    [invocation getArgument:argbuffer atIndex:i];
+                    [invocation getArgument:argbuffer atIndex:i]; // LCOV_BR_EXCL_LINE
 
                     // LCOV_EXCL_START
                 } @catch (NSObject* exc) {
@@ -594,7 +585,7 @@ static PyObject* _Nullable get_method_for_selector(PyObject* obj, SEL aSelector)
         } else { // LCOV_EXCL_LINE
             Py_BEGIN_ALLOW_THREADS
                 @try {
-                    [invocation setReturnValue:retbuffer];
+                    [invocation setReturnValue:retbuffer]; // LCOV_BR_EXCL_LINE
 
                     // LCOV_EXCL_START
                 } @catch (NSObject* localException) {
@@ -606,22 +597,23 @@ static PyObject* _Nullable get_method_for_selector(PyObject* obj, SEL aSelector)
         }
 
     PyObjC_END_WITH_GIL
-}
+} // LCOV_BR_EXCL_LINE
 
 - (PyObject* _Nullable)__pyobjc_PythonObject__
 {
+    PyObject* rv = NULL;
     PyObjC_BEGIN_WITH_GIL
         /* XXX: This is a bit too magic. Can pyObject ever be NULL?
          * and why not return None in that case?
          */
         if (pyObject == NULL) {
-            PyObject* r = PyObjCObject_New(self, PyObjCObject_kDEFAULT, YES);
-            PyObjC_GIL_RETURN(r);
+            rv = PyObjCObject_New(self, PyObjCObject_kDEFAULT, YES);
         } else {
             Py_XINCREF(pyObject);
-            PyObjC_GIL_RETURN(pyObject);
+            rv = pyObject;
         }
     PyObjC_END_WITH_GIL
+    return rv;
 }
 
 // LCOV_EXCL_START
@@ -671,7 +663,7 @@ static PyObject* _Nullable get_method_for_selector(PyObject* obj, SEL aSelector)
 
 - (id)valueForKey:(NSString*)key
 {
-    id        res = nil;
+    id res = nil;
 
     PyObjC_BEGIN_WITH_GIL
         if (PyObjC_GetKey(pyObject, key, &res) == -1) {
@@ -727,7 +719,7 @@ static PyObject* _Nullable get_method_for_selector(PyObject* obj, SEL aSelector)
 
 - (id _Nullable)valueForKeyPath:(NSString*)keyPath
 {
-    id        res = nil;
+    id res = nil;
 
     PyObjC_BEGIN_WITH_GIL
         if (PyObjC_GetKeyPath(pyObject, keyPath, &res) == -1) {
@@ -789,8 +781,6 @@ static PyObject* _Nullable get_method_for_selector(PyObject* obj, SEL aSelector)
 }
 // LCOV_EXCL_STOP
 
-
-
 // LCOV_EXCL_START
 /* These are defined for NSObject, but are only invoked by
  * the setValue:forKey: implementation, and ours never does
@@ -863,6 +853,7 @@ static PyObject* _Nullable get_method_for_selector(PyObject* obj, SEL aSelector)
         return YES;
     }
 
+    BOOL rv;
     PyObjC_BEGIN_WITH_GIL
         PyObject* otherPyObject = id_to_python(anObject);
         if (otherPyObject == NULL) {
@@ -879,11 +870,13 @@ static PyObject* _Nullable get_method_for_selector(PyObject* obj, SEL aSelector)
         case -1:
             PyErr_Clear();
         case 0:
-            PyObjC_GIL_RETURN(NO);
+            rv = NO;
+            break;
         default:
-            PyObjC_GIL_RETURN(YES);
-        } // LCOV_EXCL_LINE
+            rv = YES;
+        }
     PyObjC_END_WITH_GIL
+    return rv;
 }
 
 /* NSObject methods */
@@ -896,6 +889,9 @@ static PyObject* _Nullable get_method_for_selector(PyObject* obj, SEL aSelector)
     } else if (self == other) {
         return NSOrderedSame;
     }
+
+    NSComparisonResult rval;
+
     PyObjC_BEGIN_WITH_GIL
         PyObject* otherPyObject = id_to_python(other);
         if (otherPyObject == NULL) {
@@ -911,7 +907,6 @@ static PyObject* _Nullable get_method_for_selector(PyObject* obj, SEL aSelector)
         if (PyObjC_Cmp(pyObject, otherPyObject, &r) == -1) {
             PyObjC_GIL_FORWARD_EXC();
         } // LCOV_EXCL_LINE
-        NSComparisonResult rval;
         switch (r) {
         case -1:
             rval = NSOrderedAscending;
@@ -922,8 +917,8 @@ static PyObject* _Nullable get_method_for_selector(PyObject* obj, SEL aSelector)
         default:
             rval = NSOrderedDescending;
         }
-        PyObjC_GIL_RETURN(rval);
     PyObjC_END_WITH_GIL
+    return rval;
 }
 
 /*
@@ -981,11 +976,9 @@ static PyObject* _Nullable get_method_for_selector(PyObject* obj, SEL aSelector)
             // LCOV_EXCL_STOP
         } // LCOV_EXCL_LINE
 
-        if (temp != (NSObject*)self) {
-            [temp retain];
-            [self release];
-            self = (OC_PythonObject*)temp;
-        }
+        [temp retain];
+        [self release];
+        self = (OC_PythonObject*)temp;
         Py_DECREF(pyObject);
 
     PyObjC_END_WITH_GIL
@@ -993,7 +986,7 @@ static PyObject* _Nullable get_method_for_selector(PyObject* obj, SEL aSelector)
     return self;
 }
 
-- (id _Nullable)awakeAfterUsingCoder:(NSCoder*)__attribute__((__unused__))coder
+- (id _Nullable)awakeAfterUsingCoder:(NSCoder*)__attribute__((__unused__)) coder
 {
     return self;
 }
@@ -1001,7 +994,8 @@ static PyObject* _Nullable get_method_for_selector(PyObject* obj, SEL aSelector)
 #pragma clang diagnostic push
 #pragma clang diagnostic ignored "-Wdeprecated-declarations"
 
-- (NSObject*)replacementObjectForArchiver:(NSArchiver*)__attribute__((__unused__))archiver
+- (NSObject*)replacementObjectForArchiver:(NSArchiver*)__attribute__((__unused__))
+                                          archiver
 {
     return (NSObject*)self;
 }
@@ -1014,12 +1008,12 @@ static PyObject* _Nullable get_method_for_selector(PyObject* obj, SEL aSelector)
 #pragma clang diagnostic pop
 
 - (NSObject*)replacementObjectForKeyedArchiver:
-    (NSKeyedArchiver*)__attribute__((__unused__))archiver
+    (NSKeyedArchiver*)__attribute__((__unused__)) archiver
 {
     return (NSObject*)self;
 }
 
-- (NSObject*)replacementObjectForCoder:(NSCoder*)__attribute__((__unused__))archiver
+- (NSObject*)replacementObjectForCoder:(NSCoder*)__attribute__((__unused__)) archiver
 {
     return (NSObject*)self;
 }
@@ -1125,5 +1119,4 @@ static PyObjC_ATOMIC CFTypeID _NSObjectTypeID;
 
 @end /* OC_PythonObject class implementation */
 
-
 NS_ASSUME_NONNULL_END
