@@ -33,7 +33,7 @@ enum {
  */
 
 static Class gGlobalBlockClass = nil;
-static Class gStackBlockClass = nil;
+static Class gStackBlockClass  = nil;
 
 struct block_descriptor {
     unsigned long int reserved;
@@ -93,9 +93,9 @@ oc_copy_helper(void* _dst, void* _src)
     struct block_literal* src = (struct block_literal*)_src;
 
     PyObjC_BEGIN_WITH_GIL
-        dst->invoke_cleanup = Py_XNewRef(src->invoke_cleanup);
+        dst->invoke_cleanup    = Py_XNewRef(src->invoke_cleanup);
         dst->descriptor_memory = Py_XNewRef(src->descriptor_memory);
-        dst->signature_memory = Py_XNewRef(src->signature_memory);
+        dst->signature_memory  = Py_XNewRef(src->signature_memory);
 
     PyObjC_END_WITH_GIL
 }
@@ -121,14 +121,15 @@ static struct block_descriptor gDescriptorTemplate = {
     .signature      = 0,
 };
 
-static struct block_literal gLiteralTemplate = {.isa            = 0,
-                                                .flags          = BLOCK_HAS_COPY_DISPOSE,
-                                                .reserved       = 0,
-                                                .invoke         = NULL,
-                                                .descriptor     = &gDescriptorTemplate,
-                                                .invoke_cleanup = NULL,
-                                                .descriptor_memory = NULL,
-                                                .signature_memory = NULL,
+static struct block_literal gLiteralTemplate = {
+    .isa               = 0,
+    .flags             = BLOCK_HAS_COPY_DISPOSE,
+    .reserved          = 0,
+    .invoke            = NULL,
+    .descriptor        = &gDescriptorTemplate,
+    .invoke_cleanup    = NULL,
+    .descriptor_memory = NULL,
+    .signature_memory  = NULL,
 };
 
 /*
@@ -144,7 +145,7 @@ PyObject* _Nullable PyObjCBlock_Call(PyObject* module __attribute__((__unused__)
                                      PyObject* func_args)
 {
     PyObject*              self;
-    PyObjCMethodSignature* signature;
+    PyObjCMethodSignature* methinfo;
     PyObject*              args;
     PyObject*              kwds;
     NSObject*              block_ptr;
@@ -164,7 +165,7 @@ PyObject* _Nullable PyObjCBlock_Call(PyObject* module __attribute__((__unused__)
     ffi_cif                cif;
     PyObject*              retval;
 
-    if (!PyArg_ParseTuple(func_args, "OOOO", &self, &signature, &args, &kwds)) {
+    if (!PyArg_ParseTuple(func_args, "OOOO", &self, &methinfo, &args, &kwds)) {
         return NULL;
     }
 
@@ -173,12 +174,12 @@ PyObject* _Nullable PyObjCBlock_Call(PyObject* module __attribute__((__unused__)
         return NULL;
     }
 
-    if ((PyObject*)signature == Py_None) {
+    if ((PyObject*)methinfo == Py_None) {
         PyErr_SetString(PyExc_TypeError, "cannot call block without a signature");
         return NULL;
     }
 
-    if (!PyObjCMethodSignature_Check(signature)) {
+    if (!PyObjCMethodSignature_Check(methinfo)) {
         PyErr_SetString(PyExc_TypeError, "signature is not a signature object");
         return NULL;
     }
@@ -193,53 +194,47 @@ PyObject* _Nullable PyObjCBlock_Call(PyObject* module __attribute__((__unused__)
 
     call_func = PyObjCBlock_GetFunction(block_ptr);
 
-    argbuf_len = PyObjCRT_SizeOfReturnType(signature->rettype->type);
+    argbuf_len = PyObjCRT_SizeOfReturnType(methinfo->rettype->type);
     argbuf_len = align(argbuf_len, sizeof(void*));
 
 #ifndef __arm64__
-    int useStret = PyObjCRT_ResultUsesStret(signature->rettype->type);
+    int useStret = PyObjCRT_ResultUsesStret(methinfo->rettype->type);
     if (useStret == -1) {
         goto error;
     }
 #endif
 
     argbuf_len += sizeof(void*); /* Argument 0: the block itself */
-    r = PyObjCFFI_CountArguments(signature, 1, &byref_in_count, &byref_out_count,
+    r = PyObjCFFI_CountArguments(methinfo, 1, &byref_in_count, &byref_out_count,
                                  &plain_count, &argbuf_len, &variadicAllArgs);
     if (r == -1) {
         return NULL;
     }
 
-    variadicAllArgs |= signature->variadic
-                       && (signature->null_terminated_array || signature->arrayArg != -1);
+    variadicAllArgs |= methinfo->variadic
+                       && (methinfo->null_terminated_array || methinfo->arrayArg != -1);
 
     if (variadicAllArgs) {
         if (byref_in_count != 0 || byref_out_count != 0) {
-            PyErr_Format(PyExc_TypeError,
-                         "printf format with by-ref args not supported");
+            PyErr_Format(PyExc_TypeError, "printf format with by-ref args not supported");
             return NULL;
         }
 
-        if (PyTuple_Size(args) < Py_SIZE(signature) - 1) {
-            PyErr_Format(PyExc_TypeError,
-                         "Need %" PY_FORMAT_SIZE_T "d arguments, got %" PY_FORMAT_SIZE_T
-                         "d",
-                         Py_SIZE(signature) - 1, PyTuple_Size(args));
+        if (PyTuple_Size(args) < Py_SIZE(methinfo) - 1) {
+            PyErr_Format(PyExc_TypeError, "Need %ld arguments, got %ld",
+                         Py_SIZE(methinfo) - 1, PyTuple_Size(args));
             return NULL;
         }
 
-
-    } else if (PyTuple_Size(args) != Py_SIZE(signature) - 1) {
-        PyErr_Format(PyExc_TypeError,
-                     "Need %" PY_FORMAT_SIZE_T "d arguments, got %" PY_FORMAT_SIZE_T "d",
-                     Py_SIZE(signature) - 1, PyTuple_Size(args));
+    } else if (PyTuple_Size(args) != Py_SIZE(methinfo) - 1) {
+        PyErr_Format(PyExc_TypeError, "Need %ld arguments, got %ld",
+                     Py_SIZE(methinfo) - 1, PyTuple_Size(args));
         return NULL;
     }
 
     if (PyTuple_Size(args) > MAX_ARGCOUNT - 1) {
         PyErr_Format(PyExc_TypeError,
-                     "At most %d arguments are supported, got %" PY_FORMAT_SIZE_T
-                     "d arguments",
+                     "At most %d arguments are supported, got %ld arguments",
                      MAX_ARGCOUNT, PyTuple_Size(args));
         return NULL;
     }
@@ -252,14 +247,14 @@ PyObject* _Nullable PyObjCBlock_Call(PyObject* module __attribute__((__unused__)
 
 #ifdef __arm64__
     cif_arg_count = PyObjCFFI_ParseArguments(
-        signature, 1, PyTuple_ITEMS(args), PyTuple_GET_SIZE(args),
-        align(PyObjCRT_SizeOfReturnType(signature->rettype->type), sizeof(void*))
+        methinfo, 1, PyTuple_ITEMS(args), PyTuple_GET_SIZE(args),
+        align(PyObjCRT_SizeOfReturnType(methinfo->rettype->type), sizeof(void*))
             + sizeof(void*),
         argbuf, argbuf_len, byref, byref_attr, arglist, values);
 #else
     cif_arg_count = PyObjCFFI_ParseArguments(
-        signature, 1, PyTuple_ITEMS(args), PyTuple_GET_SIZE(args),
-        align(PyObjCRT_SizeOfReturnType(signature->rettype->type), sizeof(void*))
+        methinfo, 1, PyTuple_ITEMS(args), PyTuple_GET_SIZE(args),
+        align(PyObjCRT_SizeOfReturnType(methinfo->rettype->type), sizeof(void*))
             + sizeof(void*),
         argbuf, argbuf_len, byref, byref_attr, useStret ? arglist + 1 : arglist,
         useStret ? values + 1 : values);
@@ -276,13 +271,13 @@ PyObject* _Nullable PyObjCBlock_Call(PyObject* module __attribute__((__unused__)
 #pragma clang diagnostic push
 #pragma clang diagnostic ignored "-Wunguarded-availability-new"
 
-    if (signature->variadic) {
-        r = ffi_prep_cif_var(&cif, FFI_DEFAULT_ABI, (int)Py_SIZE(signature),
+    if (methinfo->variadic) {
+        r = ffi_prep_cif_var(&cif, FFI_DEFAULT_ABI, (int)Py_SIZE(methinfo),
                              (int)cif_arg_count,
-                             PyObjCFFI_Typestr2FFI(signature->rettype->type), arglist);
+                             PyObjCFFI_Typestr2FFI(methinfo->rettype->type), arglist);
     } else {
         r = ffi_prep_cif(&cif, FFI_DEFAULT_ABI, (int)cif_arg_count,
-                         PyObjCFFI_Typestr2FFI(signature->rettype->type), arglist);
+                         PyObjCFFI_Typestr2FFI(methinfo->rettype->type), arglist);
     }
 #pragma clang diagnostic pop
 
@@ -300,19 +295,19 @@ PyObject* _Nullable PyObjCBlock_Call(PyObject* module __attribute__((__unused__)
 
 #if PyObjC_BUILD_RELEASE >= 1015
     if (@available(macOS 10.15, *)) {
-        if (signature->variadic) {
+        if (methinfo->variadic) {
             r = ffi_prep_cif_var(
                 &cif, FFI_DEFAULT_ABI,
-                (int)(useStret ? Py_SIZE(signature) + 1 : Py_SIZE(signature)),
+                (int)(useStret ? Py_SIZE(methinfo) + 1 : Py_SIZE(methinfo)),
                 (int)(useStret ? cif_arg_count + 1 : cif_arg_count),
                 useStret ? &ffi_type_void
-                         : PyObjCFFI_Typestr2FFI(signature->rettype->type),
+                         : PyObjCFFI_Typestr2FFI(methinfo->rettype->type),
                 arglist);
         } else {
             r = ffi_prep_cif(&cif, FFI_DEFAULT_ABI,
                              (int)(useStret ? cif_arg_count + 1 : cif_arg_count),
                              useStret ? &ffi_type_void
-                                      : PyObjCFFI_Typestr2FFI(signature->rettype->type),
+                                      : PyObjCFFI_Typestr2FFI(methinfo->rettype->type),
                              arglist);
         }
     } else
@@ -320,7 +315,7 @@ PyObject* _Nullable PyObjCBlock_Call(PyObject* module __attribute__((__unused__)
     {
         r = ffi_prep_cif(
             &cif, FFI_DEFAULT_ABI, (int)(useStret ? cif_arg_count + 1 : cif_arg_count),
-            useStret ? &ffi_type_void : PyObjCFFI_Typestr2FFI(signature->rettype->type),
+            useStret ? &ffi_type_void : PyObjCFFI_Typestr2FFI(methinfo->rettype->type),
             arglist);
     }
 
@@ -328,7 +323,8 @@ PyObject* _Nullable PyObjCBlock_Call(PyObject* module __attribute__((__unused__)
 
     if (r != FFI_OK) { // LCOV_BR_EXCL_LINE
         // LCOV_EXCL_START
-        PyErr_Format(PyExc_RuntimeError, "Cannot setup FFI CIF [%d]", r);
+        PyErr_Format(PyObjCExc_Error, "Cannot create FFI CIF for %s: %s", methinfo,
+                     PyObjC_ffi_status_str((ffi_status)r));
         goto error;
         // LCOV_EXCL_STOP
     }
@@ -337,7 +333,7 @@ PyObject* _Nullable PyObjCBlock_Call(PyObject* module __attribute__((__unused__)
         @try {
             ffi_call(&cif, FFI_FN(call_func), argbuf, values);
 
-        } @catch (NSObject* localException) { // LCOV_BR_EXCL_LINE
+        } @catch (NSObject* localException) {   // LCOV_BR_EXCL_LINE
             PyObjCErr_FromObjC(localException); // LCOV_BR_EXCL_LINE
         }
     Py_END_ALLOW_THREADS
@@ -353,19 +349,18 @@ PyObject* _Nullable PyObjCBlock_Call(PyObject* module __attribute__((__unused__)
     }
 
 #ifdef __arm64__
-    retval = PyObjCFFI_BuildResult(signature, 1, argbuf, byref, byref_attr,
+    retval = PyObjCFFI_BuildResult(methinfo, 1, argbuf, byref, byref_attr,
                                    byref_out_count, values);
 #else
-    retval =
-        PyObjCFFI_BuildResult(signature, 1, argbuf, byref, byref_attr, byref_out_count,
-                              useStret ? values + 1 : values);
+    retval = PyObjCFFI_BuildResult(methinfo, 1, argbuf, byref, byref_attr,
+                                   byref_out_count, useStret ? values + 1 : values);
 #endif
 
     if (variadicAllArgs) {
-        PyObjCFFI_FreeByRef(Py_SIZE(signature) + PyTuple_Size(args), byref, byref_attr);
+        PyObjCFFI_FreeByRef(Py_SIZE(methinfo) + PyTuple_Size(args), byref, byref_attr);
 
     } else {
-        PyObjCFFI_FreeByRef(Py_SIZE(signature), byref, byref_attr);
+        PyObjCFFI_FreeByRef(Py_SIZE(methinfo), byref, byref_attr);
     }
 
     PyMem_Free(argbuf);
@@ -374,9 +369,9 @@ PyObject* _Nullable PyObjCBlock_Call(PyObject* module __attribute__((__unused__)
 
 error:
     if (variadicAllArgs) {
-        PyObjCFFI_FreeByRef(Py_SIZE(signature) + PyTuple_Size(args), byref, byref_attr);
+        PyObjCFFI_FreeByRef(Py_SIZE(methinfo) + PyTuple_Size(args), byref, byref_attr);
     } else {
-        PyObjCFFI_FreeByRef(Py_SIZE(signature), byref, byref_attr);
+        PyObjCFFI_FreeByRef(Py_SIZE(methinfo), byref, byref_attr);
     }
     if (argbuf) { // LCOV_BR_EXCL_LINE
         PyMem_Free(argbuf);
@@ -387,28 +382,29 @@ error:
 static void
 PyObjCBlock_CleanupCapsule(PyObject* ptr)
 {
-    PyObjCBlockFunction block_func = (PyObjCBlockFunction)PyCapsule_GetPointer(ptr, "objc.__block_release__");
+    PyObjCBlockFunction block_func =
+        (PyObjCBlockFunction)PyCapsule_GetPointer(ptr, "objc.__block_release__");
     if (block_func == NULL) // LCOV_BR_EXCL_LINE
-        return; // LCOV_EXCL_LINE
+        return;             // LCOV_EXCL_LINE
 
     PyObjCFFI_FreeBlockFunction(block_func);
 } // LCOV_BR_EXCL_LINE
 
-static PyObject* _Nullable block_signature(PyObjCMethodSignature* signature)
+static PyObject* _Nullable block_signature(PyObjCMethodSignature* methinfo)
 {
     Py_ssize_t i;
     Py_ssize_t buflen = 1;
-    PyObject*      buf;
+    PyObject*  buf;
     char*      cur;
 
-    buflen += strlen(signature->rettype->type);
-    for (i = 0; i < Py_SIZE(signature); i++) {
-        buflen += strlen(signature->argtype[i]->type);
+    buflen += strlen(methinfo->rettype->type);
+    for (i = 0; i < Py_SIZE(methinfo); i++) {
+        buflen += strlen(methinfo->argtype[i]->type);
     }
 
     buf = PyBytes_FromStringAndSize(NULL, buflen);
-    if (buf == NULL) {    // LCOV_BR_EXCL_LINE
-        return NULL;      // LCOV_EXCL_LINE
+    if (buf == NULL) { // LCOV_BR_EXCL_LINE
+        return NULL;   // LCOV_EXCL_LINE
     }
 
     cur = PyBytes_AsString(buf);
@@ -418,33 +414,36 @@ static PyObject* _Nullable block_signature(PyObjCMethodSignature* signature)
         return NULL;
         // LCOV_EXCL_STOP
     }
-    strlcpy(cur, signature->rettype->type, buflen);
-    for (i = 0; i < Py_SIZE(signature); i++) {
-        strlcat(cur, signature->argtype[i]->type, buflen);
+    strlcpy(cur, methinfo->rettype->type, buflen);
+    for (i = 0; i < Py_SIZE(methinfo); i++) {
+        strlcat(cur, methinfo->argtype[i]->type, buflen);
     }
     return buf;
 }
 
-void* _Nullable PyObjCBlock_Create(PyObjCMethodSignature* signature, PyObject* callable)
+void* _Nullable PyObjCBlock_Create(PyObjCMethodSignature* methinfo, PyObject* callable)
 {
     struct block_literal block = gLiteralTemplate;
 
     assert(gGlobalBlockClass != Nil);
+    assert(callable != NULL);
 
-    block.descriptor_memory = PyBytes_FromStringAndSize(NULL, sizeof(struct block_descriptor));
+    block.descriptor_memory =
+        PyBytes_FromStringAndSize(NULL, sizeof(struct block_descriptor));
     if (block.descriptor_memory == NULL) { // LCOV_BR_EXCL_LINE
-        return NULL; // LCOV_EXCL_LINE
+        return NULL;                       // LCOV_EXCL_LINE
     }
-    block.descriptor = (struct block_descriptor*)PyBytes_AsString(block.descriptor_memory);
+    block.descriptor =
+        (struct block_descriptor*)PyBytes_AsString(block.descriptor_memory);
     *(block.descriptor) = *(gLiteralTemplate.descriptor);
 
-    /* The value of "signature->signature" cannot be trusted, it
+    /* The value of "methinfo->signature" cannot be trusted, it
      * contains the raw signature without any updates from metadata.
      * Furthermore the value is bogus for block signatures in metadata.
      *
      * The function below only fails when running out of memory
      */
-    block.signature_memory = block_signature(signature);
+    block.signature_memory = block_signature(methinfo);
     if (block.signature_memory == NULL) { // LCOV_BR_EXCL_LINE
         // LCOV_EXCL_START
         Py_CLEAR(block.descriptor_memory);
@@ -453,8 +452,8 @@ void* _Nullable PyObjCBlock_Create(PyObjCMethodSignature* signature, PyObject* c
     }
     block.descriptor->signature = PyBytes_AsString(block.signature_memory);
     block.flags |= BLOCK_HAS_SIGNATURE;
-    block.isa                     = gStackBlockClass;
-    PyObjCBlockFunction block_func = PyObjCFFI_MakeBlockFunction(signature, callable);
+    block.isa                      = gStackBlockClass;
+    PyObjCBlockFunction block_func = PyObjCFFI_MakeBlockFunction(methinfo, callable);
     if (block_func == NULL) {
         Py_CLEAR(block.descriptor_memory);
         Py_CLEAR(block.signature_memory);
@@ -463,8 +462,8 @@ void* _Nullable PyObjCBlock_Create(PyObjCMethodSignature* signature, PyObject* c
     block.invoke = block_func;
 
     block.invoke_cleanup = PyCapsule_New((void*)(block.invoke), "objc.__block_release__",
-                                          PyObjCBlock_CleanupCapsule);
-    if (block.invoke_cleanup == NULL) {            // LCOV_BR_EXCL_LINE
+                                         PyObjCBlock_CleanupCapsule);
+    if (block.invoke_cleanup == NULL) { // LCOV_BR_EXCL_LINE
         // LCOV_EXCL_START
         PyObjCFFI_FreeBlockFunction(block.invoke);
         Py_CLEAR(block.descriptor_memory);
@@ -532,8 +531,8 @@ static PyObject* _Nullable pyobjc_PythonTransient(NSObject* self,
 
     self = [self copy];
 
-    *cookie = 1;
-    PyObject* result  = PyObjCObject_New(self, PyObjCObject_kDEFAULT, YES);
+    *cookie          = 1;
+    PyObject* result = PyObjCObject_New(self, PyObjCObject_kDEFAULT, YES);
     [self release];
     if (result == NULL) {
         return NULL;
@@ -557,7 +556,7 @@ PyObjCBlock_Setup(PyObject* module __attribute__((__unused__)))
     gGlobalBlockClass = GlobalBlock;
 
     StackBlock = objc_lookUpClass("__NSStackBlock__");
-    if (StackBlock == Nil) {             // LCOV_BR_EXCL_LINE
+    if (StackBlock == Nil) { // LCOV_BR_EXCL_LINE
         // LCOV_EXCL_START
         /* This should never happen... */
         PyErr_SetString(PyObjCExc_InternalError, "Cannot find __NSGlobalBlock__ class");
@@ -568,7 +567,7 @@ PyObjCBlock_Setup(PyObject* module __attribute__((__unused__)))
 
     if (!class_addMethod(StackBlock, // LCOV_BR_EXCL_LINE
                          @selector(__pyobjc_PythonObject__), (IMP)pyobjc_PythonObject,
-                             "^{_object}@:")) {
+                         "^{_object}@:")) {
         // LCOV_EXCL_START
         PyErr_SetString(PyObjCExc_InternalError, "Cannot initialize block support");
         return -1;
@@ -584,7 +583,7 @@ PyObjCBlock_Setup(PyObject* module __attribute__((__unused__)))
     }
     if (!class_addMethod(GlobalBlock, // LCOV_BR_EXCL_LINE
                          @selector(__pyobjc_PythonObject__), (IMP)pyobjc_PythonObject,
-                             "^{_object}@:")) {
+                         "^{_object}@:")) {
         // LCOV_EXCL_START
         PyErr_SetString(PyObjCExc_InternalError, "Cannot initialize block support");
         return -1;
