@@ -25,9 +25,7 @@ typedef struct {
     PyObject* _Nullable doc;
     PyObject* _Nullable name;
     PyObject* _Nullable module;
-#if PY_VERSION_HEX >= 0x03090000
     vectorcallfunc vectorcall;
-#endif
 } func_object;
 
 static PyObject* _Nullable func_metadata(PyObject* _self)
@@ -54,12 +52,10 @@ static PyMethodDef func_methods[] = {
      .ml_meth  = (PyCFunction)func_metadata,
      .ml_flags = METH_NOARGS,
      .ml_doc   = "Return a dict that describes the metadata for this function."},
-#if PY_VERSION_HEX > 0x03090000
     {.ml_name  = "__class_getitem__",
      .ml_meth  = (PyCFunction)Py_GenericAlias,
-     .ml_flags = METH_O|METH_CLASS,
+     .ml_flags = METH_O | METH_CLASS,
      .ml_doc   = "See PEP 585"},
-#endif
     {
         .ml_name = NULL /* SENTINEL */
     }};
@@ -89,14 +85,12 @@ static PyMemberDef func_members[] = {{
                                          .type   = T_OBJECT,
                                          .offset = offsetof(func_object, module),
                                      },
-#if PY_VERSION_HEX >= 0x03090000
                                      {
                                          .name   = "__vectorcalloffset__",
                                          .type   = T_PYSSIZET,
                                          .offset = offsetof(func_object, vectorcall),
                                          .flags  = READONLY,
                                      },
-#endif
                                      {
                                          .name = NULL /* SENTINEL */
                                      }};
@@ -148,7 +142,7 @@ static PyObject* _Nullable func_vectorcall(PyObject* s, PyObject* const* args,
     if (version_is_deprecated(self->methinfo->deprecated)) {
         char buf[128];
 
-        snprintf(buf, 128, "%s() is a deprecated API (macOS %d.%d)",
+        snprintf(buf, 128, "%s() is a deprecated API (macOS %d.%d)", // LCOV_BR_EXCL_LINE
                  (self->name ? PyUnicode_AsUTF8(self->name) : "objc.function instance"),
                  self->methinfo->deprecated / 100, self->methinfo->deprecated % 100);
 
@@ -164,8 +158,7 @@ static PyObject* _Nullable func_vectorcall(PyObject* s, PyObject* const* args,
 
     if (Py_SIZE(self->methinfo) >= 63) {
         PyErr_Format(PyObjCExc_Error,
-                     "wrapping a function with %" PY_FORMAT_SIZE_T
-                     "d arguments, at most 62 "
+                     "wrapping a function with %ld arguments, at most 62 "
                      "are supported",
                      Py_SIZE(self->methinfo));
         return NULL;
@@ -175,7 +168,7 @@ static PyObject* _Nullable func_vectorcall(PyObject* s, PyObject* const* args,
     argbuf_len = align(argbuf_len, sizeof(void*));
     r = PyObjCFFI_CountArguments(self->methinfo, 0, &byref_in_count, &byref_out_count,
                                  &plain_count, &argbuf_len, &variadicAllArgs);
-    if (r == -1) { // LCOV_BR_EXCL_LINE
+    if (r == -1) {   // LCOV_BR_EXCL_LINE
         return NULL; // LCOV_EXCL_LINE
     }
 
@@ -185,20 +178,18 @@ static PyObject* _Nullable func_vectorcall(PyObject* s, PyObject* const* args,
 
     if (variadicAllArgs) {
         if (byref_in_count != 0 || byref_out_count != 0) {
-            PyErr_Format(PyExc_TypeError,
-                         "Sorry, printf format with by-ref args not supported");
+            PyErr_Format(PyExc_TypeError, "variadic with by-ref args not supported");
             return NULL;
         }
 
         if (nargsf < (size_t)Py_SIZE(self->methinfo)) {
-            PyErr_Format(PyExc_TypeError,
-                         "Need %" PY_FORMAT_SIZE_T "d arguments, got %zu",
-                         Py_SIZE(self->methinfo) - 2, nargsf);
+            PyErr_Format(PyExc_TypeError, "Need at least %ld arguments, got %zu",
+                         Py_SIZE(self->methinfo), nargsf);
             return NULL;
         }
 
     } else if (nargsf != (size_t)Py_SIZE(self->methinfo)) {
-        PyErr_Format(PyExc_TypeError, "Need %" PY_FORMAT_SIZE_T "d arguments, got %zu",
+        PyErr_Format(PyExc_TypeError, "Need %ld arguments, got %zu",
                      Py_SIZE(self->methinfo), nargsf);
         return NULL;
     }
@@ -250,7 +241,8 @@ static PyObject* _Nullable func_vectorcall(PyObject* s, PyObject* const* args,
 
         if (r != FFI_OK) { // LCOV_BR_EXCL_LINE
             // LCOV_EXCL_START
-            PyErr_Format(PyExc_RuntimeError, "Cannot setup FFI CIF [%d]", r);
+            PyErr_Format(PyObjCExc_Error, "Cannot create FFI CIF for %s: %s",
+                         self->methinfo->signature, PyObjC_ffi_status_str((ffi_status)r));
             goto error;
             // LCOV_EXCL_STOP
         }
@@ -264,8 +256,8 @@ static PyObject* _Nullable func_vectorcall(PyObject* s, PyObject* const* args,
         @try {
             ffi_call(cifptr, FFI_FN(self->function), argbuf, values);
 
-        } @catch (NSObject* localException) {
-            PyObjCErr_FromObjC(localException);
+        } @catch (NSObject* localException) {   // LCOV_BR_EXCL_LINE
+            PyObjCErr_FromObjC(localException); // LCOV_BR_EXCL_LINE
         }
     Py_END_ALLOW_THREADS
 
@@ -284,14 +276,11 @@ error:
         PyObjCFFI_FreeByRef(Py_SIZE(self->methinfo), byref, byref_attr);
     }
 
-    if (argbuf) {
-        PyMem_Free(argbuf);
-        argbuf = NULL;
-    }
+    assert(argbuf != NULL);
+    PyMem_Free(argbuf);
     return retval;
 }
 
-#if PY_VERSION_HEX >= 0x03090000
 /*
  * A variant of func_vectorcall that only handles "simple" functions. This allows
  * for a number of simplifications that significantly speed up functions calls
@@ -333,8 +322,7 @@ static PyObject* _Nullable func_vectorcall_simple(PyObject* s, PyObject* const*
     }
 
     if (unlikely(nargsf != (size_t)Py_SIZE(self->methinfo))) {
-        PyErr_Format(PyExc_TypeError,
-                     "Need %" PY_FORMAT_SIZE_T "d arguments, got %" PY_FORMAT_SIZE_T "d",
+        PyErr_Format(PyExc_TypeError, "Need %ld arguments, got %ld",
                      Py_SIZE(self->methinfo), nargsf);
         return NULL;
     }
@@ -351,8 +339,8 @@ static PyObject* _Nullable func_vectorcall_simple(PyObject* s, PyObject* const*
     Py_BEGIN_ALLOW_THREADS
         @try {
             ffi_call(self->cif, FFI_FN(self->function), argbuf, values);
-        } @catch (id localException) {
-            PyObjCErr_FromObjC((NSObject*)localException);
+        } @catch (id localException) {                     // LCOV_BR_EXCL_LINE
+            PyObjCErr_FromObjC((NSObject*)localException); // LCOV_BR_EXCL_LINE
         }
     Py_END_ALLOW_THREADS
 
@@ -365,20 +353,6 @@ static PyObject* _Nullable func_vectorcall_simple(PyObject* s, PyObject* const*
 error:
     return NULL;
 }
-#endif
-
-#if PY_VERSION_HEX < 0x03090000
-static PyObject* _Nullable func_call(PyObject* s, PyObject* _Nullable args,
-                                     PyObject* _Nullable kwds)
-{
-    if (kwds != NULL && (!PyDict_Check(kwds) || PyDict_Size(kwds) != 0)) {
-        PyErr_SetString(PyExc_TypeError, "keyword arguments not supported");
-        return NULL;
-    }
-
-    return func_vectorcall(s, PyTuple_ITEMS(args), PyTuple_GET_SIZE(args), NULL);
-}
-#endif
 
 static void
 func_dealloc(PyObject* s)
@@ -431,11 +405,7 @@ static PyType_Slot func_slots[] = {
 #if PY_VERSION_HEX < 0x030a0000
     {.slot = Py_tp_new, .pfunc = (void*)&func_new},
 #endif
-#if PY_VERSION_HEX >= 0x03090000
     {.slot = Py_tp_call, .pfunc = (void*)&PyVectorcall_Call},
-#else
-    {.slot = Py_tp_call, .pfunc = (void*)&func_call},
-#endif
 
     {0, NULL} /* sentinel */
 };
@@ -447,11 +417,8 @@ static PyType_Spec func_spec = {
 #if PY_VERSION_HEX >= 0x030a0000
     .flags = Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HEAPTYPE | Py_TPFLAGS_IMMUTABLETYPE
              | Py_TPFLAGS_HAVE_VECTORCALL | Py_TPFLAGS_DISALLOW_INSTANTIATION,
-#elif PY_VERSION_HEX >= 0x03090000
-    .flags = Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_VECTORCALL | Py_TPFLAGS_HEAPTYPE,
-
 #else
-    .flags = Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HEAPTYPE,
+    .flags = Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_VECTORCALL | Py_TPFLAGS_HEAPTYPE,
 #endif
     .slots = func_slots,
 };
@@ -467,16 +434,18 @@ PyObject* _Nullable PyObjCFunc_WithMethodSignature(PyObject* _Nullable name, voi
     if (result == NULL) // LCOV_BR_EXCL_LINE
         return NULL;    // LCOV_EXCL_LINE
 
-#if PY_VERSION_HEX >= 0x03090000
     result->vectorcall = func_vectorcall;
-#endif
-    result->function = func;
-    result->doc      = NULL;
-    result->name     = name;
+    result->function   = func;
+    result->doc        = NULL;
+    result->name       = name;
     Py_XINCREF(name);
     result->module   = NULL;
     result->methinfo = methinfo;
     Py_XINCREF(methinfo);
+    if (result->methinfo->shortcut_signature) {
+        result->vectorcall = func_vectorcall_simple;
+    }
+    result->cif = NULL;
 
     ffi_cif* cif = PyObjCFFI_CIFForSignature(result->methinfo);
     if (cif == NULL) {
@@ -503,10 +472,8 @@ PyObject* _Nullable PyObjCFunc_New(PyObject* name, void* func, const char* signa
     if (result == NULL) // LCOV_BR_EXCL_LINE
         return NULL;    // LCOV_EXCL_LINE
 
-#if PY_VERSION_HEX >= 0x03090000
     result->vectorcall = func_vectorcall;
-#endif
-    result->function = func;
+    result->function   = func;
 
     /* set later in this function */
     result->doc      = (PyObject* _Nonnull)NULL;
@@ -523,11 +490,9 @@ PyObject* _Nullable PyObjCFunc_New(PyObject* name, void* func, const char* signa
     }
     result->methinfo = methinfo;
 
-#if PY_VERSION_HEX >= 0x03090000
     if (result->methinfo->shortcut_signature) {
         result->vectorcall = func_vectorcall_simple;
     }
-#endif
 
     SET_FIELD_INCREF(result->doc, doc);
     SET_FIELD_INCREF(result->name, name);
@@ -556,7 +521,8 @@ PyObjCFunc_Setup(PyObject* module)
     }
 
     if (PyModule_AddObject( // LCOV_BR_EXCL_LINE
-            module, "function", PyObjCFunc_Type) == -1) {
+            module, "function", PyObjCFunc_Type)
+        == -1) {
         return -1; // LCOV_EXCL_LINE
     }
     Py_INCREF(PyObjCFunc_Type);
