@@ -83,11 +83,9 @@ static PyObject* _Nullable object_repr(PyObject* _self)
 {
     PyObjCObject* self = (PyObjCObject*)_self;
     PyObject*     res;
-    unsigned int flags;
+    unsigned int  flags;
 
-    Py_BEGIN_CRITICAL_SECTION(_self);
     flags = self->flags;
-    Py_END_CRITICAL_SECTION();
 
     if (flags & PyObjCObject_kMAGIC_COOKIE) { // LCOV_BR_EXCL_LINE
         // LCOV_EXCL_START
@@ -120,7 +118,7 @@ static PyObject* _Nullable object_repr(PyObject* _self)
     }
 
     res = PyUnicode_FromFormat("<%s objective-c instance %p>", Py_TYPE(self)->tp_name,
-                                self->objc_object);
+                               self->objc_object);
 
     return res;
 }
@@ -213,7 +211,7 @@ object_verify_type(PyObject* obj)
         if (tp == NULL) { // LCOV_BR_EXCL_LINE
             // LCOV_EXCL_START
             PyErr_Format(PyObjCExc_Error, "Cannot get class for Objective-C class '%s'",
-                    class_getName((Class _Nonnull)object_getClass(obj_inst)));
+                         class_getName((Class _Nonnull)object_getClass(obj_inst)));
             return -1;
             // LCOV_EXCL_STOP
         }
@@ -253,16 +251,17 @@ object_verify_type(PyObject* obj)
             Py_END_CRITICAL_SECTION();
             Py_XDECREF(tmp);
             if (did_change) {
-                if (PyObjCClass_CheckMethodList((PyObject*)tp, 0) < 0) { // LCOV_BR_EXCL_LINE
+                if (PyObjCClass_CheckMethodList((PyObject*)tp, 0)
+                    < 0) { // LCOV_BR_EXCL_LINE
                     // LCOV_EXCL_START
                     Py_DECREF(tp);
                     return -1;
                     // LCOV_EXCL_STOP
                 }
             }
-        }
+        } // LCOV_EXCL_LINE
         Py_CLEAR(tp);
-    }
+    } // LCOV_EXCL_LINE
     return 0;
 }
 
@@ -287,10 +286,10 @@ static inline PyObject* _Nullable _type_lookup(PyTypeObject* tp, PyObject* name,
     Py_ssize_t i, n;
     PyObject * mro, *base, *dict;
 #ifdef PyObjC_ENABLE_LOOKUP_CACHE
-    PyObject*  first_class = NULL;
+    PyObject* first_class = NULL;
 #endif
-    PyObject*  descr       = NULL;
-    SEL        sel         = PyObjCSelector_DefaultSelector(name_bytes);
+    PyObject* descr = NULL;
+    SEL       sel   = PyObjCSelector_DefaultSelector(name_bytes);
 
     /* Look in tp_dict of types in MRO */
     Py_BEGIN_CRITICAL_SECTION(tp);
@@ -315,9 +314,9 @@ static inline PyObject* _Nullable _type_lookup(PyTypeObject* tp, PyObject* name,
             if (cache != NULL) {
                 int r = PyDict_GetItemRef(cache, name, &descr);
                 Py_CLEAR(cache);
-                if (r == -1) {    // LCOV_BR_EXCL_LINE
+                if (r == -1) { // LCOV_BR_EXCL_LINE
                     Py_CLEAR(mro);
-                    return NULL;  // LCOV_EXCL_LINE
+                    return NULL; // LCOV_EXCL_LINE
                 } else if (r == 1) {
                     break;
                 }
@@ -335,7 +334,6 @@ static inline PyObject* _Nullable _type_lookup(PyTypeObject* tp, PyObject* name,
 
         } else if (PyType_Check(base)) { // LCOV_BR_EXCL_LINE
 
-
             dict = PyType_GetDict((PyTypeObject*)base);
 
         } else {
@@ -353,7 +351,7 @@ static inline PyObject* _Nullable _type_lookup(PyTypeObject* tp, PyObject* name,
 
         int r = PyDict_GetItemRef(dict, name, &descr);
         Py_CLEAR(dict);
-        if (r == -1) {   // LCOV_BR_EXCL_LINE
+        if (r == -1) { // LCOV_BR_EXCL_LINE
             // LCOV_EXCL_START
             Py_CLEAR(mro);
             return NULL;
@@ -488,21 +486,21 @@ static inline PyObject* _Nullable _type_lookup_harder(PyTypeObject* tp, PyObject
                 SEL         meth_name = method_getName(m);
 
                 if (encoding == NULL) { // LCOV_BR_EXCL_LINE
-                    //LCOV_EXCL_START
+                    // LCOV_EXCL_START
                     free(methods);
                     Py_CLEAR(mro);
                     PyErr_SetString(PyObjCExc_Error,
                                     "Native selector with Nil type encoding");
                     return NULL;
-                    //LCOV_EXCL_STOP
+                    // LCOV_EXCL_STOP
                 }
                 if (meth_name == NULL) { // LCOV_BR_EXCL_LINE
-                    //LCOV_EXCL_START
+                    // LCOV_EXCL_START
                     free(methods);
                     Py_CLEAR(mro);
                     PyErr_SetString(PyObjCExc_Error, "Native selector with Nil selector");
                     return NULL;
-                    //LCOV_EXCL_STOP
+                    // LCOV_EXCL_STOP
                 }
 
                 /* Create (unbound) selector */
@@ -518,7 +516,8 @@ static inline PyObject* _Nullable _type_lookup_harder(PyTypeObject* tp, PyObject
 
                 /* add to __dict__ 'cache' */
                 /* 'base' is a PyObjClass instance, using tp_dict is safe */
-                if (PyDict_SetItem(((PyTypeObject*)base)->tp_dict, name, descr)
+                if (PyDict_SetItem( // LCOV_BR_EXCL_LINE
+                        ((PyTypeObject*)base)->tp_dict, name, descr)
                     == -1) { // LCOV_BR_EXCL_LINE
                     // LCOV_EXCL_START
                     Py_DECREF(descr);
@@ -565,8 +564,8 @@ static PyObject* _Nullable object_getattro(PyObject* obj, PyObject* name)
         return NULL;       // LCOV_EXCL_LINE
     }
 
-    if (object_verify_type(obj) == -1) {
-        goto done;
+    if (object_verify_type(obj) == -1) { // LCOV_BR_EXCL_LINE
+        goto done;                       // LCOV_EXCL_LINE
     }
 
     tp = Py_TYPE(obj);
@@ -606,7 +605,7 @@ static PyObject* _Nullable object_getattro(PyObject* obj, PyObject* name)
             }
         } else {
             PyErr_Format(PyExc_AttributeError, "'%.50s' object has no attribute '%.400s'",
-                 tp->tp_name, namestr);
+                         tp->tp_name, namestr);
         }
         goto done;
     }
@@ -619,7 +618,7 @@ static PyObject* _Nullable object_getattro(PyObject* obj, PyObject* name)
 
         if (PyObjC_is_ascii_string(name, "__dict__")) {
 
-            res = *(PyObject* PyObjC_ATOMIC *)dictptr;
+            res = *(PyObject * PyObjC_ATOMIC*)dictptr;
             if (res == NULL) {
                 res = PyDict_New();
 
@@ -629,11 +628,11 @@ static PyObject* _Nullable object_getattro(PyObject* obj, PyObject* name)
                  */
                 PyObject* to_clear = NULL;
                 Py_BEGIN_CRITICAL_SECTION(obj);
-                if (*(PyObject* PyObjC_ATOMIC *)dictptr == NULL) {
-                    *(PyObject* PyObjC_ATOMIC *)dictptr = res;
+                if (*(PyObject * PyObjC_ATOMIC*)dictptr == NULL) {
+                    *(PyObject * PyObjC_ATOMIC*)dictptr = res;
                 } else {
                     to_clear = res;
-                    res = *(PyObject* PyObjC_ATOMIC *)dictptr;
+                    res      = *(PyObject * PyObjC_ATOMIC*)dictptr;
                 }
                 Py_END_CRITICAL_SECTION();
                 Py_CLEAR(to_clear);
@@ -648,7 +647,7 @@ static PyObject* _Nullable object_getattro(PyObject* obj, PyObject* name)
             dict = *dictptr;
             if (dict != NULL) {
                 switch (PyDict_GetItemRef( // LCOV_BR_EXCL_LINE
-                            dict, name, &res)) {
+                    dict, name, &res)) {
                 case -1:
                     goto done; // LCOV_EXCL_LINE
                 /* case 0: pass */
@@ -688,7 +687,7 @@ static PyObject* _Nullable object_getattro(PyObject* obj, PyObject* name)
     }
 
     if (descr != NULL) {
-        res = descr;
+        res   = descr;
         descr = NULL;
         goto done;
     }
@@ -726,12 +725,17 @@ object_setattro(PyObject* obj, PyObject* name, PyObject* _Nullable value)
     NSString*     obj_name;
     const char*   namestr;
 
-    if (!PyUnicode_Check(name)) {
+    if (!PyUnicode_Check(name)) { // LCOV_BR_EXCL_LINE
+        /* The CPython runtime ensures that 'name' is a string unless someone
+         * directly invokes the ``tp_setattro`` slot.
+         */
+        // LCOV_EXCL_START
         PyErr_Format(PyExc_TypeError, "attribute name must be string, got %s",
                      Py_TYPE(name)->tp_name);
         return -1;
+        // LCOV_EXCL_STOP
     }
-    namestr = PyObjC_Unicode_Fast_Bytes(name);
+    namestr = PyUnicode_AsUTF8(name);
     if (namestr == NULL) {
         return -1;
     }
@@ -741,12 +745,15 @@ object_setattro(PyObject* obj, PyObject* name, PyObject* _Nullable value)
     obj_name = nil;
     if (((PyObjCClassObject*)tp)->useKVO) {
         if (!PyObjC_is_ascii_prefix(name, "_", 1)) {
-            obj_name =
-                [NSString stringWithUTF8String:(const char* _Nonnull)PyObjC_Unicode_Fast_Bytes(name)];
+            obj_name = [NSString
+                stringWithUTF8String:(const char* _Nonnull)PyUnicode_AsUTF8(name)];
 
-            if (obj_name == nil) {
-                PyErr_SetString(PyObjCExc_Error, "Cannot convert attribute name to NSString");
+            if (obj_name == nil) { // LCOV_BR_EXCL_LINE
+                // LCOV_EXCL_START
+                PyErr_SetString(PyObjCExc_Error,
+                                "Cannot convert attribute name to NSString");
                 return -1;
+                // LCOV_EXCL_STOP
             }
 
             @try {
@@ -780,9 +787,11 @@ object_setattro(PyObject* obj, PyObject* name, PyObject* _Nullable value)
 
         if (dict == NULL && value != NULL) {
             dict = PyDict_New();
-            if (dict == NULL) {
+            if (dict == NULL) { // LCOV_BR_EXCL_LINE
+                // LCOV_EXCL_START
                 res = -1;
                 goto done;
+                // LCOV_EXCL_STOP
             }
 
             /* free-threading: setting *dictptr must
@@ -795,7 +804,7 @@ object_setattro(PyObject* obj, PyObject* name, PyObject* _Nullable value)
                 *dictptr = dict;
             } else {
                 to_clear = dict;
-                dict = *dictptr;
+                dict     = *dictptr;
             }
             Py_END_CRITICAL_SECTION();
             Py_CLEAR(to_clear);
@@ -809,7 +818,7 @@ object_setattro(PyObject* obj, PyObject* name, PyObject* _Nullable value)
                 res = PyDict_SetItem(dict, name, value);
             }
 
-            if (res < 0 && PyErr_ExceptionMatches(PyExc_KeyError)) {
+            if (res < 0 && PyErr_ExceptionMatches(PyExc_KeyError)) { // LCOV_BR_EXCL_LINE
                 PyErr_SetObject(PyExc_AttributeError, name);
             }
             goto done;
@@ -823,13 +832,13 @@ object_setattro(PyObject* obj, PyObject* name, PyObject* _Nullable value)
 
     if (descr == NULL) {
         PyErr_Format(PyExc_AttributeError, "'%.50s' object has no attribute '%.400s'",
-                     tp->tp_name, PyObjC_Unicode_Fast_Bytes(name));
+                     tp->tp_name, PyUnicode_AsUTF8(name));
         res = -1;
         goto done;
     }
 
     PyErr_Format(PyExc_AttributeError, "'%.50s' object attribute '%.400s' is read-only",
-                 tp->tp_name, PyObjC_Unicode_Fast_Bytes(name));
+                 tp->tp_name, PyUnicode_AsUTF8(name));
     res = -1;
 done:
     Py_CLEAR(descr);
@@ -860,7 +869,7 @@ static PyObject* _Nullable objc_get_real_class(PyObject* self,
     /* object_getClass only return Nil if its argument is nil */
     ret = PyObjCClass_New((Class _Nonnull)object_getClass(objc_object));
     if (ret == NULL) { // LCOV_BR_EXCL_LINE
-        return NULL; // LCOV_EXCL_LINE
+        return NULL;   // LCOV_EXCL_LINE
     }
     if (ret != (PyObject*)Py_TYPE(self)) {
         Py_BEGIN_CRITICAL_SECTION(self);
@@ -944,7 +953,8 @@ obj_set_blocksignature(PyObject* self, PyObject* _Nullable newVal,
         return -1;
     }
 
-    PyObjCMethodSignature* result = PyObjCObject_SetBlockSignature(self, (PyObjCMethodSignature*)newVal);
+    PyObjCMethodSignature* result =
+        PyObjCObject_SetBlockSignature(self, (PyObjCMethodSignature*)newVal);
     Py_DECREF(newVal);
     Py_XDECREF(result);
     if (result != NULL && newVal != (PyObject*)result) {
@@ -999,9 +1009,8 @@ static PyObject* _Nullable meth_sizeof(PyObject* self __attribute__((__unused__)
     id objc_value = PyObjCObject_GetObject(self);
     assert(objc_value != nil);
 
-    return PyLong_FromSize_t(
-            Py_TYPE(self)->tp_basicsize
-            + class_getInstanceSize(object_getClass(objc_value)));
+    return PyLong_FromSize_t(Py_TYPE(self)->tp_basicsize
+                             + class_getInstanceSize(object_getClass(objc_value)));
 }
 
 static PyObject*
@@ -1022,7 +1031,6 @@ static PyObject* _Nullable as_cobject(PyObject* self)
     return PyCapsule_New(self_value, "objc.__object__", NULL);
 }
 
-
 static PyObject* _Nullable as_ctypes_voidp(PyObject* self)
 {
     id self_value = PyObjCObject_OBJECT(self);
@@ -1051,8 +1059,9 @@ static PyObject* _Nullable meth_dir(PyObject* self)
 
     PyObject** dictptr = _get_dictptr(self);
     if (dictptr != NULL && *dictptr != NULL) {
-        PyObject* args[] = { NULL, result, *dictptr };
-        PyObject* tmp = PyObject_VectorcallMethod(PyObjCNM_update, args+1, 2|PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
+        PyObject* args[] = {NULL, result, *dictptr};
+        PyObject* tmp    = PyObject_VectorcallMethod(
+            PyObjCNM_update, args + 1, 2 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
         if (tmp == NULL) { // LCOV_BR_EXCL_LINE
             // LCOV_EXCL_START
             Py_CLEAR(result);
@@ -1114,7 +1123,7 @@ static PyObject* _Nullable meth_dir(PyObject* self)
                 // LCOV_EXCL_STOP
             }
             Py_DECREF(item);
-        }
+        } // LCOV_EXCL_LINE
         free(methods);
 
         cls = class_getSuperclass(cls);
@@ -1191,13 +1200,13 @@ PyObject* _Nullable _PyObjCObject_NewDeallocHelper(id objc_object)
     cls_type =
         (PyTypeObject*)PyObjCClass_New((Class _Nonnull)object_getClass(objc_object));
     if (cls_type == NULL) { // LCOV_BR_EXCL_LINE
-        return NULL; // LCOV_EXCL_LINE
+        return NULL;        // LCOV_EXCL_LINE
     }
 
     res = cls_type->tp_alloc(cls_type, 0);
     Py_DECREF(cls_type);
     if (res == NULL) { // LCOV_BR_EXCL_LINE
-        return NULL; // LCOV_EXCL_LINE
+        return NULL;   // LCOV_EXCL_LINE
     }
 
     if (PyObjCClass_CheckMethodList((PyObject*)Py_TYPE(res), 1) < 0) {
@@ -1214,7 +1223,7 @@ PyObject* _Nullable _PyObjCObject_NewDeallocHelper(id objc_object)
 void
 _PyObjCObject_FreeDeallocHelper(PyObject* obj)
 {
-#if PY_VERSION_HEX >= 0x030e0000
+#ifdef Py_GIL_DISABLED
     if (PyUnstable_Object_IsUniquelyReferenced(obj) != 1) {
 #else
     if (Py_REFCNT(obj) != 1) {
@@ -1265,7 +1274,7 @@ PyObject* _Nullable PyObjCObject_New(id objc_object, int flags, int retain)
         // LCOV_EXCL_START
         if (!PyErr_Occurred()) {
             PyErr_Format(PyObjCExc_Error, "Cannot find python proxy for class '%s'",
-                class_getName(cls));
+                         class_getName(cls));
         }
         return NULL;
         // LCOV_EXCL_STOP
@@ -1274,7 +1283,7 @@ PyObject* _Nullable PyObjCObject_New(id objc_object, int flags, int retain)
     res = cls_type->tp_alloc(cls_type, 0);
     Py_DECREF(cls_type);
     if (res == NULL) { // LCOV_BR_EXCL_LINE
-        return NULL; // LCOV_EXCL_LINE
+        return NULL;   // LCOV_EXCL_LINE
     }
 
     if (cls_type->tp_basicsize == sizeof(PyObjCBlockObject)) {
@@ -1321,24 +1330,30 @@ PyObject* _Nullable PyObjCObject_FindSelector(PyObject* object, SEL selector)
     return PyObjCClass_FindSelector((PyObject*)Py_TYPE(object), selector, NO);
 }
 
-id PyObjCObject_GetObject(PyObject* object)
+id
+PyObjCObject_GetObject(PyObject* object)
 {
     id result = PyObjCObject_OBJECT(object);
     return result;
 }
 
-unsigned int PyObjCObject_GetFlags(PyObject* object)
+unsigned int
+PyObjCObject_GetFlags(PyObject* object)
 {
-    return PyObjCObject_FLAGS(object);
+    unsigned int result = PyObjCObject_FLAGS(object);
+    assert((result & ~PyObjCObject_kALL_FLAGS) == 0);
+    return result;
 }
 
-bool PyObjCObject_IsBlock(PyObject* object)
+bool
+PyObjCObject_IsBlock(PyObject* object)
 {
     assert(PyObjCObject_Check(object));
     return (PyObjCObject_FLAGS(object) & PyObjCObject_kBLOCK) != 0;
 }
 
-bool PyObjCObject_IsMagic(PyObject* object)
+bool
+PyObjCObject_IsMagic(PyObject* object)
 {
     assert(PyObjCObject_Check(object));
     return (PyObjCObject_FLAGS(object) & PyObjCObject_kMAGIC_COOKIE) != 0;
@@ -1355,7 +1370,8 @@ PyObjCMethodSignature* _Nullable PyObjCObject_GetBlockSignature(PyObject* object
     return result;
 }
 
-PyObjCMethodSignature* _Nullable PyObjCObject_SetBlockSignature(PyObject* object, PyObjCMethodSignature* methinfo)
+PyObjCMethodSignature*
+PyObjCObject_SetBlockSignature(PyObject* object, PyObjCMethodSignature* methinfo)
 {
     assert(PyObjCObject_IsBlock(object));
     PyObjCMethodSignature* result;
@@ -1371,18 +1387,11 @@ PyObjCMethodSignature* _Nullable PyObjCObject_SetBlockSignature(PyObject* object
     return result;
 }
 
-
-
-PyObject* _Nullable PyObjCObject_GetAttr(PyObject* obj, PyObject* name)
-{
-    return object_getattro(obj, name);
-}
-
 PyObject* _Nullable PyObjCObject_GetAttrString(PyObject* obj, char* name)
 {
     PyObject* pyname = PyUnicode_FromString(name);
     if (pyname == NULL) // LCOV_BR_EXCL_LINE
-        return NULL; // LCOV_EXCL_START
+        return NULL;    // LCOV_EXCL_START
 
     PyObject* rv = object_getattro(obj, pyname);
     Py_DECREF(pyname);
