@@ -48,7 +48,7 @@ static PyObject* _Nullable super_getattro(PyObject* self, PyObject* name)
     }
 
     if (PyUnicode_Check(name)) { // LCOV_BR_EXCL_LINE
-        const char* b = PyObjC_Unicode_Fast_Bytes(name);
+        const char* b = PyUnicode_AsUTF8(name);
         if (b == NULL) { // LCOV_BR_EXCL_LINE
             return NULL; // LCOV_EXCL_LINE
         }
@@ -113,7 +113,7 @@ static PyObject* _Nullable super_getattro(PyObject* self, PyObject* name)
                 continue; // LCOV_EXCL_LINE
             }
 
-            switch(PyDict_GetItemRef(dict, name, &res)) { // LCOV_BR_EXCL_LINE
+            switch (PyDict_GetItemRef(dict, name, &res)) { // LCOV_BR_EXCL_LINE
             case -1:
                 // LCOV_EXCL_START
                 Py_CLEAR(dict);
@@ -165,13 +165,13 @@ static PyObject* _Nullable super_getattro(PyObject* self, PyObject* name)
                     return res;
 
                 } else if (PyErr_Occurred()) { // LCOV_BR_EXCL_LINE
-                    Py_CLEAR(dict);             // LCOV_EXCL_LINE
+                    Py_CLEAR(dict);            // LCOV_EXCL_LINE
                     return NULL;               // LCOV_EXCL_LINE
                 }
             }
             Py_CLEAR(dict);
         }
-    }
+    } // LCOV_EXCL_LINE
     return PyObject_GenericGetAttr(self, name);
 }
 
@@ -200,12 +200,10 @@ PyObjCSuper_Setup(PyObject* module)
     super_slots[1].pfunc = (void*)(PySuper_Type.tp_doc);
 
 #if PY_VERSION_HEX < 0x030a0000
-    PyObject* bases = PyTuple_New(1);
+    PyObject* bases = PyTuple_Pack(1, (PyObject*)&PySuper_Type);
     if (bases == NULL) {
         return -1;
     }
-    PyTuple_SET_ITEM(bases, 0, (PyObject*)&PySuper_Type);
-    Py_INCREF(&PySuper_Type);
 #endif
 
     PyObject* tmp = PyType_FromSpecWithBases(&super_spec,
