@@ -155,16 +155,12 @@ static PyObject* _Nullable opaque_new(PyTypeObject* type, PyObject* _Nullable ar
 static void
 opaque_dealloc(PyObject* self)
 {
-#if PY_VERSION_HEX >= 0x03090000
     PyTypeObject* tp = Py_TYPE(self);
-#endif
 
     PyObject_GC_UnTrack(self);
     PyObject_GC_Del(self);
 
-#if PY_VERSION_HEX >= 0x03090000
     Py_DECREF(tp);
-#endif /* PY_VERSION_HEX >= 0x03090000 */
 }
 
 static int
@@ -172,9 +168,7 @@ opaque_traverse(PyObject* self __attribute__((__unused__)),
                 visitproc visit __attribute__((__unused__)),
                 void*     arg __attribute__((__unused__)))
 {
-#if PY_VERSION_HEX >= 0x03090000
     Py_VISIT(Py_TYPE(self));
-#endif /* PY_VERSION_HEX >= 0x03090000 */
     return 0;
 }
 
@@ -186,8 +180,7 @@ opaque_from_c(ffi_cif* cif __attribute__((__unused__)), void* retval, void** arg
     PyTypeObject*        opaque_type   = (PyTypeObject*)userdata;
     OpaquePointerObject* result;
 
-    if (pointer_value == NULL)     // LCOV_BR_EXCL_LINE
-        PyObjCErr_InternalError(); // LCOV_EXCL_LINE
+    assert(pointer_value != NULL);
 
     result = PyObject_GC_New(OpaquePointerObject, opaque_type);
     if (result == NULL) { // LCOV_BR_EXCL_LINE
@@ -324,7 +317,7 @@ PyObject* _Nullable PyObjCCreateOpaquePointerType(const char* name, const char*
             goto error_cleanup;
         }
         strcpy(buf, "objc.");
-        strlcpy(buf + 5, name, sizeof(buf)-5);
+        strlcpy(buf + 5, name, sizeof(buf) - 5);
     }
 
     PyType_Spec opaque_spec = {
@@ -338,7 +331,7 @@ PyObject* _Nullable PyObjCCreateOpaquePointerType(const char* name, const char*
 
     if (opaque_spec.name == NULL) { // LCOV_BR_EXCL_LINE
         goto error_cleanup;         // LCOV_EXCL_LINE
-    }                               // LCOV_EXCL_LINE
+    } // LCOV_EXCL_LINE
 
     newType = PyType_FromSpec(&opaque_spec);
     if (newType == NULL) {                   // LCOV_BR_EXCL_LINE
@@ -426,11 +419,11 @@ error_cleanup:
 #pragma clang diagnostic ignored "-Wunguarded-availability-new"
     if (cl_to_c) {                 // LCOV_BR_EXCL_LINE
         ffi_closure_free(cl_to_c); // LCOV_EXCL_LINE
-    }                              // LCOV_EXCL_LINE
+    } // LCOV_EXCL_LINE
 
     if (cl_from_c) {                 // LCOV_BR_EXCL_LINE
         ffi_closure_free(cl_from_c); // LCOV_EXCL_LINE
-    }                                // LCOV_EXCL_LINE
+    } // LCOV_EXCL_LINE
 #pragma clang diagnostic pop
 #endif
     Py_XDECREF(newType);
