@@ -36,15 +36,13 @@ typedef struct {
     Class _Nullable sel_class;
     int sel_flags;
     PyObjCMethodSignature* _Nullable sel_methinfo;
-    Py_ssize_t sel_mappingcount;
-#if PY_VERSION_HEX >= 0x03090000
+    Py_ssize_t     sel_mappingcount;
     vectorcallfunc sel_vectorcall;
-#endif
 } PyObjCSelector;
 
 typedef struct {
     PyObjCSelector base;
-    PyObjC_ATOMIC PyObjC_CallFunc _Nullable sel_call_func;
+    PyObjC_ATOMIC  PyObjC_CallFunc _Nullable sel_call_func;
     ffi_cif* _Nullable sel_cif;
 } PyObjCNativeSelector;
 
@@ -52,7 +50,6 @@ typedef struct {
     PyObjCSelector base;
     PyObject*      callable;
     Py_ssize_t     argcount;
-    Py_ssize_t     numoutput; /* XXX: To be removed, only set and never read */
 } PyObjCPythonSelector;
 
 extern PyObject* PyObjCSelector_Type;
@@ -68,12 +65,12 @@ extern PyObject* PyObjCPythonSelector_Type;
 extern const char* PyObjCSelector_Signature(PyObject* obj);
 #define PyObjCSelector_GetNativeSignature(obj)                                           \
     (((PyObjCSelector*)obj)->sel_native_signature)
-extern SEL PyObjCSelector_GetSelector(PyObject* obj);
-extern int PyObjCSelector_GetFlags(PyObject* obj);
+extern SEL   PyObjCSelector_GetSelector(PyObject* obj);
+extern int   PyObjCSelector_GetFlags(PyObject* obj);
 extern Class PyObjCSelector_GetClass(PyObject* obj);
-extern int PyObjCSelector_Required(PyObject* obj);
-extern int PyObjCSelector_IsClassMethod(PyObject* obj);
-extern int PyObjCSelector_IsHidden(PyObject* obj);
+extern int   PyObjCSelector_Required(PyObject* obj);
+extern int   PyObjCSelector_IsClassMethod(PyObject* obj);
+extern int   PyObjCSelector_IsHidden(PyObject* obj);
 extern PyObjCMethodSignature* _Nullable PyObjCSelector_GetMetadata(PyObject* _self);
 extern PyObject* _Nullable PyObjCSelector_NewNative(Class class, SEL selector,
                                                     const char* signature,
@@ -92,6 +89,9 @@ extern SEL PyObjCSelector_DefaultSelector(const char* methname);
 
 extern int PyObjCSelector_Setup(PyObject* module);
 
+extern PyObjC_CallFunc _Nullable PyObjCSelector_GetCallFunc(
+    PyObjCNativeSelector* obj, PyObjCMethodSignature* methinfo);
+
 NS_ASSUME_NONNULL_END
 
 #endif /* PyObjC_SELECTOR_H */
