@@ -6,23 +6,18 @@
  *
  * - Call the method from python
  * - Call the python implementation of a method from Objective-C
- *
- * XXX: Add API to dump the registry for inspection.
  */
 #include "pyobjc.h"
 
 NS_ASSUME_NONNULL_BEGIN
 
-/* XXX: Use a minimal python type instead of a capsule */
 struct registry {
     PyObjC_CallFunc         call_to_objc;
     PyObjC_MakeIMPBlockFunc make_call_to_python_block;
 };
 
-
 #ifdef Py_GIL_DISABLED
-/* XXX: Consider using two mutexes */
-static PyMutex registry_mutex = { 0 };
+static PyMutex registry_mutex = {0};
 #endif
 
 /* Dict mapping from signature-string to a 'struct registry' */
@@ -51,7 +46,6 @@ PyObjC_InitSuperCallRegistry(void)
     return 0;
 }
 
-
 // LCOV_EXCL_START
 /* The code in this file only adds new values to
  * the registry, but never clears them. Because of
@@ -62,11 +56,7 @@ memblock_capsule_cleanup(PyObject* ptr)
 {
     void* mem = PyCapsule_GetPointer(ptr, "objc.__memblock__");
 
-#ifdef PyObjC_DEBUG
-    if (mem == NULL)
-        PyObjCErr_InternalError();
-#endif
-
+    assert(mem != NULL);
     PyMem_Free(mem);
 }
 // LCOV_EXCL_STOP
@@ -83,12 +73,12 @@ PyObjC_RegisterMethodMapping(_Nullable Class class, SEL sel, PyObjC_CallFunc cal
     PyObject*        entry;
     PyObject*        lst;
     PyObject*        py_selname;
-    int r;
-    int retval =  0;
+    int              r;
+    int              retval = 0;
 
     assert(special_registry != NULL);
-    assert(call_to_objc !=  NULL);
-    assert(make_call_to_python_block !=  NULL);
+    assert(call_to_objc != NULL);
+    assert(make_call_to_python_block != NULL);
 
 #ifdef Py_GIL_DISABLED
     PyMutex_Lock(&registry_mutex);
@@ -140,21 +130,16 @@ PyObjC_RegisterMethodMapping(_Nullable Class class, SEL sel, PyObjC_CallFunc cal
     v->call_to_objc              = call_to_objc;
     v->make_call_to_python_block = make_call_to_python_block;
 
-    entry = PyTuple_New(2);
+    entry = Py_BuildValue(
+        "(ON)", pyclass, PyCapsule_New(v, "objc.__memblock__", memblock_capsule_cleanup));
     if (entry == NULL) { // LCOV_BR_EXCL_LINE
         // LCOV_EXCL_START
         Py_DECREF(py_selname);
-        Py_DECREF(pyclass);
-        PyMem_Free(v);
         retval = -1;
         goto exit;
         // LCOV_EXCL_STOP
     }
 
-    PyTuple_SET_ITEM(entry, 0, pyclass);
-    PyTuple_SET_ITEM(entry, 1,
-                     PyCapsule_New(v, "objc.__memblock__", memblock_capsule_cleanup));
-
     if (PyTuple_GET_ITEM(entry, 1) == NULL) { // LCOV_BR_EXCL_LINE
         // LCOV_EXCL_START
         Py_DECREF(py_selname);
@@ -197,7 +182,7 @@ PyObjC_RegisterMethodMapping(_Nullable Class class, SEL sel, PyObjC_CallFunc cal
         }
         Py_DECREF(py_selname);
 
-    /* case 1: fallthrough */
+        /* case 1: fallthrough */
     }
 
     if (PyList_Append(lst, entry) < 0) { // LCOV_BR_EXCL_LINE
@@ -218,7 +203,6 @@ exit:
     PyMutex_Unlock(&registry_mutex);
 #endif
     return retval;
-
 }
 
 int
@@ -324,10 +308,10 @@ static struct registry* _Nullable search_special(Class class, SEL sel)
     PyObject*  result        = NULL;
     PyObject*  special_class = NULL;
     PyObject*  search_class  = NULL;
-    PyObject*  py_selname = NULL;
+    PyObject*  py_selname    = NULL;
     PyObject*  lst;
     Py_ssize_t i;
-    int r;
+    int        r;
 
     assert(special_registry != NULL);
     assert(class != Nil);
@@ -337,7 +321,7 @@ static struct registry* _Nullable search_special(Class class, SEL sel)
 
     py_selname = PyUnicode_FromString(sel_getName(sel));
     if (py_selname == NULL) { // LCOV_BR_EXCL_LINE
-        goto error; // LCOV_EXCL_LINE
+        goto error;           // LCOV_EXCL_LINE
     }
 
     search_class = PyObjCClass_New(class);
@@ -350,7 +334,7 @@ static struct registry* _Nullable search_special(Class class, SEL sel)
         goto error; // LCOV_EXCL_LINE
     case 0:
         goto error;
-    /* case 1: fallthrough */
+        /* case 1: fallthrough */
     }
 
     /*
@@ -364,29 +348,43 @@ static struct registry* _Nullable search_special(Class class, SEL sel)
      */
     Py_ssize_t len = PyList_Size(lst);
     for (i = 0; i < len; i++) {
-        PyObject* entry   = PyList_GetItemRef(lst, i);
+        PyObject* entry = PyList_GetItemRef(lst, i);
         if (entry == NULL) { // LCOV_BR_EXCL_LINE
-            goto error; // LCOV_EXCL_LINE
+            goto error;      // LCOV_EXCL_LINE
         }
         PyObject* pyclass = PyTuple_GET_ITEM(entry, 0);
 
         if (pyclass == NULL) { // LCOV_BR_EXCL_LINE
-            Py_DECREF(entry); // LCOV_EXCL_LINE
-            continue;        // LCOV_EXCL_LINE
-        }
-        if (pyclass != Py_None
-            && !PyType_IsSubtype((PyTypeObject*)search_class, (PyTypeObject*)pyclass)) {
-            Py_DECREF(entry);
-            continue;
+            Py_DECREF(entry);  // LCOV_EXCL_LINE
+            continue;          // LCOV_EXCL_LINE
         }
 
-        if (!special_class) {
+        if (pyclass == Py_None) {
+            /* pass */
+        } else if (!PyType_IsSubtype((PyTypeObject*)search_class,
+                                     (PyTypeObject*)pyclass)) {
+            /* Current entry is not for a superclass of search_class */
+            Py_DECREF(entry);
+            continue;
+        } else {
+            /* Current entry is for a superclass of search_class */
+            if (special_class != NULL && special_class != Py_None) {
+                if (!PyType_IsSubtype((PyTypeObject*)pyclass,
+                                      (PyTypeObject*)special_class)) {
+                    /* The new class is not more specific than the old one */
+                    Py_DECREF(entry);
+                    continue;
+                }
+            }
+        }
+
+        if (special_class == NULL) {
             /* No match yet, use */
             Py_CLEAR(special_class);
             Py_CLEAR(result);
             special_class = pyclass;
-            result        = PyTuple_GET_ITEM(entry, 1);
             Py_INCREF(special_class);
+            result = PyTuple_GET_ITEM(entry, 1);
             Py_INCREF(result);
             Py_DECREF(entry);
 
@@ -395,18 +393,19 @@ static struct registry* _Nullable search_special(Class class, SEL sel)
             Py_DECREF(entry);
             continue;
 
-        } else if (PyType_IsSubtype((PyTypeObject*)special_class,
-                                    (PyTypeObject*)pyclass)) {
+        } else if (special_class == Py_None
+                   || PyType_IsSubtype((PyTypeObject*)pyclass,
+                                       (PyTypeObject*)search_class)) {
             /* special_type is a superclass of search_class,
              * but a subclass of the current match, hence it is
              * a more specific match or a similar match later in the
              * list.
              */
-            Py_CLEAR(result);
             Py_CLEAR(special_class);
-            Py_INCREF(pyclass);
+            Py_CLEAR(result);
             special_class = pyclass;
-            result        = PyTuple_GET_ITEM(entry, 1);
+            Py_INCREF(special_class);
+            result = PyTuple_GET_ITEM(entry, 1);
             Py_INCREF(result);
             Py_DECREF(entry);
         }
@@ -418,27 +417,27 @@ static struct registry* _Nullable search_special(Class class, SEL sel)
     Py_CLEAR(search_class);
     Py_CLEAR(py_selname);
 
-     struct registry* rv = PyCapsule_GetPointer(result, "objc.__memblock__");
-     Py_DECREF(result);
+    struct registry* rv = PyCapsule_GetPointer(result, "objc.__memblock__");
+    Py_DECREF(result);
 #ifdef Py_GIL_DISABLED
-     PyMutex_Unlock(&registry_mutex);
+    PyMutex_Unlock(&registry_mutex);
 #endif
-     return rv;
+    return rv;
 
 error:
-     Py_CLEAR(special_class);
-     Py_CLEAR(py_selname);
-     Py_CLEAR(search_class);
+    Py_CLEAR(special_class);
+    Py_CLEAR(py_selname);
+    Py_CLEAR(search_class);
 #ifdef Py_GIL_DISABLED
-     PyMutex_Unlock(&registry_mutex);
+    PyMutex_Unlock(&registry_mutex);
 #endif
-     return NULL;
+    return NULL;
 }
 
 static struct registry* _Nullable find_signature(const char* signature)
 {
-    PyObject* o = NULL;
-    int       res;
+    PyObject*        o = NULL;
+    int              res;
     struct registry* result = NULL;
 
     assert(signature_registry != NULL);
@@ -448,7 +447,7 @@ static struct registry* _Nullable find_signature(const char* signature)
 #endif
     PyObject* key = PyBytes_FromStringAndSize(NULL, strlen(signature) + 10);
     if (key == NULL) { // LCOV_BR_EXCL_LINE
-        goto exit; // LCOV_EXCL_LINE
+        goto exit;     // LCOV_EXCL_LINE
     }
 
     res = PyObjCRT_SimplifySignature(signature, PyBytes_AS_STRING(key),
@@ -466,9 +465,10 @@ static struct registry* _Nullable find_signature(const char* signature)
         goto exit; // LCOV_EXCL_LINE
     }
     if (PyDict_GetItemRef(signature_registry, key, &o) != 1) {
+        Py_DECREF(key);
         goto exit;
     }
-
+    Py_DECREF(key);
     result = PyCapsule_GetPointer(o, "objc.__memblock__");
     Py_DECREF(o);
 
@@ -482,7 +482,7 @@ exit:
 PyObjC_CallFunc _Nullable PyObjC_FindCallFunc(Class class, SEL sel, const char* signature)
 {
     struct registry* special;
-    PyObjC_CallFunc result;
+    PyObjC_CallFunc  result;
 
     assert(special_registry != NULL);
 
@@ -490,30 +490,29 @@ PyObjC_CallFunc _Nullable PyObjC_FindCallFunc(Class class, SEL sel, const char*
     if (special) {
         result = special->call_to_objc;
     } else if (PyErr_Occurred()) { // LCOV_BR_EXCL_LINE
-        result = NULL;               // LCOV_EXCL_LINE
+        result = NULL;             // LCOV_EXCL_LINE
     } else {
         special = find_signature(signature);
         if (special) {
             result = special->call_to_objc;
         } else if (PyErr_Occurred()) { // LCOV_BR_EXCL_LINE
-            result = NULL;               // LCOV_EXCL_LINE
-        } else { // LCOV_EXCL_LINE
+            result = NULL;             // LCOV_EXCL_LINE
+        } else {                       // LCOV_EXCL_LINE
             result = PyObjCFFI_Caller;
         }
     }
 
+    if (result == &PyObjCUnsupportedMethod_Caller) {
+        PyErr_Format(PyExc_TypeError, "Cannot call '%s' on instance of '%s' from Python",
+                     sel_getName(sel), class_getName(class));
+        result = NULL;
+    }
+
     return result;
 }
 
-/*
- * XXX: Ideally there'd be a function to clean up the IMP, that requires
- *      additional state though.
- *
- * XXX: Remove class argument
- */
 extern IMP
-PyObjC_MakeIMP(Class class __attribute__((__unused__)), Class _Nullable super_class,
-               PyObject* sel, PyObject* imp)
+PyObjC_MakeIMP(Class class, PyObject* sel)
 {
     struct registry*        generic;
     struct registry*        special;
@@ -524,11 +523,11 @@ PyObjC_MakeIMP(Class class __attribute__((__unused__)), Class _Nullable super_cl
 
     methinfo = PyObjCSelector_GetMetadata(sel);
     if (methinfo == NULL) { // LCOV_BR_EXCL_LINE
-        return NULL; // LCOV_EXCL_LINE
+        return NULL;        // LCOV_EXCL_LINE
     }
 
-    if (super_class != nil) {
-        special = search_special(super_class, aSelector);
+    if (class != nil) {
+        special = search_special(class, aSelector);
         if (special) {
             func = special->make_call_to_python_block;
         } else if (PyErr_Occurred()) { // LCOV_BR_EXCL_LINE
@@ -552,14 +551,43 @@ PyObjC_MakeIMP(Class class __attribute__((__unused__)), Class _Nullable super_cl
         return NULL;
     }
 
+    Method meth;
+    if (PyObjCSelector_IsClassMethod(sel)) {
+        meth = class_getClassMethod(class, PyObjCSelector_GetSelector(sel));
+    } else {
+        meth = class_getInstanceMethod(class, PyObjCSelector_GetSelector(sel));
+    }
+    if (meth) {
+        const char* meth_encoding = method_getTypeEncoding(meth);
+        if (meth_encoding == NULL) { // LCOV_BR_EXCL_LINE
+            /* method_getTypeEncoding should only return NULL when
+             * meth is NULL.
+             */
+            // LCOV_EXCL_START
+            PyErr_Format(PyObjCExc_BadPrototypeError,
+                         "%R cannot determine class type encoding", sel);
+            return NULL;
+            // LCOV_EXCL_STOP
+        }
+
+        if (!PyObjCRT_SignaturesEqual(meth_encoding,
+                                      PyObjCSelector_GetNativeSignature(sel))) {
+
+            PyErr_Format(
+                PyObjCExc_BadPrototypeError,
+                "%R has signature that is not compatible with ObjC runtime: %s != %s",
+                sel, meth_encoding, PyObjCSelector_GetNativeSignature(sel));
+            return NULL;
+        }
+    }
+
     if (func != NULL) {
-        retval = func(imp, methinfo);
-        return retval;
+        return func(sel, methinfo);
     } else {
         PyErr_Clear();
 
         retval =
-            PyObjCFFI_MakeIMPForSignature(methinfo, PyObjCSelector_GetSelector(sel), imp);
+            PyObjCFFI_MakeIMPForSignature(methinfo, PyObjCSelector_GetSelector(sel), sel);
 
         if (retval == NULL && PyErr_ExceptionMatches(PyExc_NotImplementedError)) {
             PyObject* exc       = NULL;
@@ -607,8 +635,16 @@ PyObjCUnsupportedMethod_Caller(PyObject* meth, PyObject* self,
                                PyObject* const* args __attribute__((__unused__)),
                                size_t           nargs __attribute__((__unused__)))
 {
+    SEL sel;
+    if (PyObjCSelector_Check(meth)) {
+        sel = PyObjCSelector_GetSelector(meth);
+    } else {
+        assert(PyObjCIMP_Check(meth));
+        sel = PyObjCIMP_GetSelector(meth);
+    }
+
     PyErr_Format(PyExc_TypeError, "Cannot call '%s' on '%R' from Python",
-                 sel_getName(PyObjCSelector_GetSelector(meth)), self);
+                 sel_getName(sel), self);
     return NULL;
 }
 // LCOV_EXCL_STOP
