@@ -24,7 +24,7 @@
 {
     static id buf[100];
 
-    if (range.length > 100) { // LCOV_BR_EXCL_LINE
+    if (range.length > 100) {     // LCOV_BR_EXCL_LINE
         return @"too many items"; // LCOV_EXCL_LINE
     }
 
@@ -42,7 +42,9 @@
     }
 }
 
-+ (id _Nullable)setNthElement:(NSMutableArray*)array offset:(NSUInteger)offset from:(Class)value
++ (id _Nullable)setNthElement:(NSMutableArray*)array
+                       offset:(NSUInteger)offset
+                         from:(Class)value
 {
     @try {
         id ref = [[value alloc] init];
@@ -76,7 +78,9 @@
     }
 }
 
-+ (id _Nullable)insertIntoArray:(NSMutableArray*)array offset:(NSUInteger)offset from:(Class)value
++ (id _Nullable)insertIntoArray:(NSMutableArray*)array
+                         offset:(NSUInteger)offset
+                           from:(Class)value
 {
     @try {
         id ref = [[value alloc] init];
@@ -131,14 +135,15 @@
 
 static PyMethodDef mod_methods[] = {{0, 0, 0, 0}};
 
-static int mod_exec_module(PyObject* m)
+static int
+mod_exec_module(PyObject* m)
 {
     if (PyObjC_ImportAPI(m) < 0) { // LCOV_BR_EXCL_LINE
-        return -1; // LCOV_EXCL_LINE
+        return -1;                 // LCOV_EXCL_LINE
     }
 
     if (PyModule_AddObject( // LCOV_BR_EXCL_LINE
-                m, "OC_ArrayInt", PyObjC_IdToPython([OC_ArrayInt class]))
+            m, "OC_ArrayInt", PyObjC_IdToPython([OC_ArrayInt class]))
         < 0) {
         return -1; // LCOV_EXCL_LINE
     }
@@ -147,42 +152,37 @@ static int mod_exec_module(PyObject* m)
 }
 
 static struct PyModuleDef_Slot mod_slots[] = {
-    {
-        .slot = Py_mod_exec,
-        .value = (void*)mod_exec_module
-    },
+    {.slot = Py_mod_exec, .value = (void*)mod_exec_module},
 #if PY_VERSION_HEX >= 0x030c0000
     {
         /* This extension does not use the CPython API other than initializing
          * the module, hence is safe with subinterpreters and per-interpreter
          * GILs
          */
-        .slot = Py_mod_multiple_interpreters,
+        .slot  = Py_mod_multiple_interpreters,
         .value = Py_MOD_PER_INTERPRETER_GIL_SUPPORTED,
     },
 #endif
 #if PY_VERSION_HEX >= 0x030d0000
     {
-        .slot = Py_mod_gil,
+        .slot  = Py_mod_gil,
         .value = Py_MOD_GIL_NOT_USED,
     },
 #endif
-    {  /* Sentinel */
-        .slot = 0,
-        .value = 0
-    }
-};
+    {/* Sentinel */
+     .slot  = 0,
+     .value = 0}};
 
 static struct PyModuleDef mod_module = {
-    .m_base = PyModuleDef_HEAD_INIT,
-    .m_name = "arrayint",
-    .m_doc = NULL,
-    .m_size = 0,
-    .m_methods = mod_methods,
-    .m_slots = mod_slots,
+    .m_base     = PyModuleDef_HEAD_INIT,
+    .m_name     = "arrayint",
+    .m_doc      = NULL,
+    .m_size     = 0,
+    .m_methods  = mod_methods,
+    .m_slots    = mod_slots,
     .m_traverse = NULL,
-    .m_clear = NULL,
-    .m_free = NULL,
+    .m_clear    = NULL,
+    .m_free     = NULL,
 };
 
 PyObject* PyInit_arrayint(void);
