@@ -28,6 +28,7 @@ typedef struct ArrayStruct struct_array_t[4];
 + (NSObject*)callArrayOf4IntsOut:(OC_ArrayTest*)object;
 + (NSObject*)callArrayOf4Structs:(OC_ArrayTest*)object;
 + (NSObject*)callArrayOf4StructsOut:(OC_ArrayTest*)object;
+
 @end
 
 @implementation OC_ArrayTest
@@ -194,15 +195,32 @@ typedef struct ArrayStruct struct_array_t[4];
                                               nil],
                          nil];
 }
+
++ (unichar*)uniarrayOf12
+{
+    static unichar buffer[13] = {'h', 'e', 'l', 'l', 'o', ',', ' ',
+                                 'w', 'o', 'r', 'l', 'd', '\0'};
+
+    return buffer;
+}
++ (unichar*)baduniarrayOf12
+{
+    /* Text with lone surrogate */
+    static unichar buffer[13] = {'h', 'e', 'l', 'l', 'o', 0xD800, ' ',
+                                 'w', 'o', 'r', 'l', 'd', '\0'};
+
+    return buffer;
+}
+
 @end
 
 static PyMethodDef mod_methods[] = {{0, 0, 0, 0}};
 
-
-static int mod_exec_module(PyObject* m)
+static int
+mod_exec_module(PyObject* m)
 {
     if (PyObjC_ImportAPI(m) < 0) { // LCOV_BR_EXCL_LINE
-        return -1; // LCOV_EXCL_LINE
+        return -1;                 // LCOV_EXCL_LINE
     }
 
     if (PyModule_AddObject(m, // LCOV_BR_EXCL_LINE
@@ -215,42 +233,37 @@ static int mod_exec_module(PyObject* m)
 }
 
 static struct PyModuleDef_Slot mod_slots[] = {
-    {
-        .slot = Py_mod_exec,
-        .value = (void*)mod_exec_module
-    },
+    {.slot = Py_mod_exec, .value = (void*)mod_exec_module},
 #if PY_VERSION_HEX >= 0x030c0000
     {
         /* This extension does not use the CPython API other than initializing
          * the module, hence is safe with subinterpreters and per-interpreter
          * GILs
          */
-        .slot = Py_mod_multiple_interpreters,
+        .slot  = Py_mod_multiple_interpreters,
         .value = Py_MOD_PER_INTERPRETER_GIL_SUPPORTED,
     },
 #endif
 #if PY_VERSION_HEX >= 0x030d0000
     {
-        .slot = Py_mod_gil,
+        .slot  = Py_mod_gil,
         .value = Py_MOD_GIL_NOT_USED,
     },
 #endif
-    {  /* Sentinel */
-        .slot = 0,
-        .value = 0
-    }
-};
+    {/* Sentinel */
+     .slot  = 0,
+     .value = 0}};
 
 static struct PyModuleDef mod_module = {
-    .m_base = PyModuleDef_HEAD_INIT,
-    .m_name = "arrays",
-    .m_doc = NULL,
-    .m_size = 0,
-    .m_methods = mod_methods,
-    .m_slots = mod_slots,
+    .m_base     = PyModuleDef_HEAD_INIT,
+    .m_name     = "arrays",
+    .m_doc      = NULL,
+    .m_size     = 0,
+    .m_methods  = mod_methods,
+    .m_slots    = mod_slots,
     .m_traverse = NULL,
-    .m_clear = NULL,
-    .m_free = NULL,
+    .m_clear    = NULL,
+    .m_free     = NULL,
 };
 
 PyObject* PyInit_arrays(void);
