@@ -5,8 +5,7 @@
 
 static void erase_signature(id _block);
 
-@interface
-NSObject (IndirectBlockTest)
+@interface NSObject (IndirectBlockTest)
 - (double)processBlock:(double (^)(double, double))aBlock;
 - (id)optionalBlock:(id (^)(id))aBlock;
 - (void)callWithCompletion:(void (^)(id))aBlock;
@@ -49,7 +48,7 @@ static int (^gIntBlock)(void) = nil;
 
 @implementation OCTestBlock
 
--(id)init
+- (id)init
 {
     self = [super init];
     if (!self) {
@@ -110,8 +109,8 @@ static int (^gIntBlock)(void) = nil;
 {
     __block int counter = 0;
     return [[^(double a, double b) {
-        counter ++;
-        return a + b + counter;
+      counter++;
+      return a + b + counter;
     } copy] autorelease];
 }
 
@@ -125,92 +124,92 @@ static int (^gIntBlock)(void) = nil;
 - (void (^)(void))getRaisingBlock
 {
     return [[^(void) {
-        [NSException raise:@"SimpleException" format:@"hello world"];
+      [NSException raise:@"SimpleException" format:@"hello world"];
     } copy] autorelease];
 }
 
 - (id (^)(id, ...))getVariadicBlock
 {
     return [[^(id first, ...) {
-        NSMutableArray* result = [NSMutableArray array];
-        va_list ap;
+      NSMutableArray* result = [NSMutableArray array];
+      va_list         ap;
 
-        va_start(ap, first);
+      va_start(ap, first);
 
-        do {
-            [result addObject:first];
+      do {
+          [result addObject:first];
 
-            first = va_arg(ap, id);
-        } while (first != nil);
+          first = va_arg(ap, id);
+      } while (first != nil);
 
-        va_end(ap);
-        return result;
+      va_end(ap);
+      return result;
     } copy] autorelease];
 }
 
 - (id (^)(const char*, ...))getPrintfBlock
 {
     return [[^(id fmt, ...) {
-        char buffer[256];
-        va_list ap;
+      char    buffer[256];
+      va_list ap;
 
-        va_start(ap, fmt);
+      va_start(ap, fmt);
 
 #pragma clang diagnostic push
 #pragma clang diagnostic ignored "-Wformat-nonliteral"
 
-        vsnprintf(buffer, sizeof(buffer), [fmt UTF8String], ap);
+      vsnprintf(buffer, sizeof(buffer), [fmt UTF8String], ap);
 #pragma clang diagnostic pop
 
-        va_end(ap);
-        return [NSString stringWithUTF8String:buffer];
+      va_end(ap);
+      return [NSString stringWithUTF8String:buffer];
     } copy] autorelease];
 }
 
 - (id (^)(const char*, ...))getPrintfBlock2
 {
     return [[^(int* output, id fmt, ...) {
-        *output=42;
-        char buffer[256];
-        va_list ap;
+      *output = 42;
+      char    buffer[256];
+      va_list ap;
 
-        va_start(ap, fmt);
+      va_start(ap, fmt);
 
 #pragma clang diagnostic push
 #pragma clang diagnostic ignored "-Wformat-nonliteral"
 
-        vsnprintf(buffer, sizeof(buffer), [fmt UTF8String], ap);
+      vsnprintf(buffer, sizeof(buffer), [fmt UTF8String], ap);
 #pragma clang diagnostic pop
 
-        va_end(ap);
-        return [NSString stringWithUTF8String:buffer];
+      va_end(ap);
+      return [NSString stringWithUTF8String:buffer];
     } copy] autorelease];
 }
 
 - (id (^)(const char*, ...))getPrintfBlock3
 {
     return [[^(int* input, id fmt, ...) {
-        *input=42;
-        char buffer[256];
-        va_list ap;
+      *input = 42;
+      char    buffer[256];
+      va_list ap;
 
-        va_start(ap, fmt);
+      va_start(ap, fmt);
 
 #pragma clang diagnostic push
 #pragma clang diagnostic ignored "-Wformat-nonliteral"
 
-        vsnprintf(buffer, sizeof(buffer), [fmt UTF8String], ap);
+      vsnprintf(buffer, sizeof(buffer), [fmt UTF8String], ap);
 #pragma clang diagnostic pop
 
-        va_end(ap);
-        return [NSString stringWithUTF8String:buffer];
+      va_end(ap);
+      return [NSString stringWithUTF8String:buffer];
     } copy] autorelease];
 }
 
-- (id(^)(id, id, id, id, id, id, id))getHugeBlock
+- (id (^)(id, id, id, id, id, id, id))getHugeBlock
 {
     return [[^(id a, id b, id c, id d, id e, id f, id g) {
-        return [NSArray arrayWithObjects:a, b, c, d, e, f, g, nil];
+      return [NSArray arrayWithObjects:a, b, c, d, e, f, g, nil];
     } copy] autorelease];
 }
 
@@ -352,7 +351,7 @@ signature_for_block(id _block)
     return [[stored_block retain] autorelease];
 }
 
--(void)dealloc
+- (void)dealloc
 {
     [stored_block release];
     stored_block = nil;
@@ -360,19 +359,18 @@ signature_for_block(id _block)
     [super dealloc];
 }
 
-
 @end
 
 static PyMethodDef mod_methods[] = {{0, 0, 0, 0}};
 
-
-static int mod_exec_module(PyObject* m)
+static int
+mod_exec_module(PyObject* m)
 {
     if (PyObjC_ImportAPI(m) < 0) { // LCOV_BR_EXCL_LINE
-        return -1; // LCOV_EXCL_LINE
+        return -1;                 // LCOV_EXCL_LINE
     }
     if (PyModule_AddObject(m, // LCOV_BR_EXCL_LINE
-                "OCTestBlock", PyObjC_IdToPython([OCTestBlock class]))
+                           "OCTestBlock", PyObjC_IdToPython([OCTestBlock class]))
         < 0) {
         return -1; // LCOV_EXCL_LINE
     }
@@ -381,42 +379,37 @@ static int mod_exec_module(PyObject* m)
 }
 
 static struct PyModuleDef_Slot mod_slots[] = {
-    {
-        .slot = Py_mod_exec,
-        .value = (void*)mod_exec_module
-    },
+    {.slot = Py_mod_exec, .value = (void*)mod_exec_module},
 #if PY_VERSION_HEX >= 0x030c0000
     {
         /* This extension does not use the CPython API other than initializing
          * the module, hence is safe with subinterpreters and per-interpreter
          * GILs
          */
-        .slot = Py_mod_multiple_interpreters,
+        .slot  = Py_mod_multiple_interpreters,
         .value = Py_MOD_PER_INTERPRETER_GIL_SUPPORTED,
     },
 #endif
 #if PY_VERSION_HEX >= 0x030d0000
     {
-        .slot = Py_mod_gil,
+        .slot  = Py_mod_gil,
         .value = Py_MOD_GIL_NOT_USED,
     },
 #endif
-    {  /* Sentinel */
-        .slot = 0,
-        .value = 0
-    }
-};
+    {/* Sentinel */
+     .slot  = 0,
+     .value = 0}};
 
 static struct PyModuleDef mod_module = {
-    .m_base = PyModuleDef_HEAD_INIT,
-    .m_name = "block",
-    .m_doc = NULL,
-    .m_size = 0,
-    .m_methods = mod_methods,
-    .m_slots = mod_slots,
+    .m_base     = PyModuleDef_HEAD_INIT,
+    .m_name     = "block",
+    .m_doc      = NULL,
+    .m_size     = 0,
+    .m_methods  = mod_methods,
+    .m_slots    = mod_slots,
     .m_traverse = NULL,
-    .m_clear = NULL,
-    .m_free = NULL,
+    .m_clear    = NULL,
+    .m_free     = NULL,
 };
 
 PyObject* PyInit_block(void);
