@@ -62,66 +62,64 @@ static PyMethodDef mod_methods[] = {{
 
                                     {0, 0, 0, 0}};
 
-static int mod_exec_module(PyObject* m)
+static int
+mod_exec_module(PyObject* m)
 {
     if (PyObjC_ImportAPI(m) < 0) { // LCOV_BR_EXCL_LINE
-        return -1; // LCOV_EXCL_LINE
+        return -1;                 // LCOV_EXCL_LINE
     }
 
     if (PyModule_AddObject(m, // LCOV_BR_EXCL_LINE
-                "OC_OpaqueTest", PyObjC_IdToPython([OC_OpaqueTest class]))
+                           "OC_OpaqueTest", PyObjC_IdToPython([OC_OpaqueTest class]))
         < 0) {
         return -1; // LCOV_EXCL_LINE
     }
 
     if (PyModule_AddObject(m, // LCOV_BR_EXCL_LINE
-                "BarEncoded", PyBytes_FromString(@encode(BarHandle))) < 0) {
+                           "BarEncoded", PyBytes_FromString(@encode(BarHandle)))
+        < 0) {
         return -1; // LCOV_EXCL_LINE
     }
     if (PyModule_AddObject(m, // LCOV_BR_EXCL_LINE
-                "FooEncoded", PyBytes_FromString(@encode(FooHandle))) < 0) {
+                           "FooEncoded", PyBytes_FromString(@encode(FooHandle)))
+        < 0) {
         return -1; // LCOV_EXCL_LINE
     }
     return 0;
 }
 
 static struct PyModuleDef_Slot mod_slots[] = {
-    {
-        .slot = Py_mod_exec,
-        .value = (void*)mod_exec_module
-    },
+    {.slot = Py_mod_exec, .value = (void*)mod_exec_module},
 #if PY_VERSION_HEX >= 0x030c0000
     {
         /* This extension does not use the CPython API other than initializing
          * the module, hence is safe with subinterpreters and per-interpreter
          * GILs
          */
-        .slot = Py_mod_multiple_interpreters,
+        .slot  = Py_mod_multiple_interpreters,
         .value = Py_MOD_PER_INTERPRETER_GIL_SUPPORTED,
     },
 #endif
 #if PY_VERSION_HEX >= 0x030d0000
     {
-        .slot = Py_mod_gil,
+        .slot  = Py_mod_gil,
         .value = Py_MOD_GIL_NOT_USED,
     },
 #endif
-    {  /* Sentinel */
-        .slot = 0,
-        .value = 0
-    }
-};
+    {/* Sentinel */
+     .slot  = 0,
+     .value = 0}};
 
 static struct PyModuleDef mod_module = {
-    .m_base = PyModuleDef_HEAD_INIT,
-    .m_name = "opaque",
-    .m_doc = NULL,
-    .m_size = 0,
-    .m_methods = mod_methods,
-    .m_slots = mod_slots,
+    .m_base     = PyModuleDef_HEAD_INIT,
+    .m_name     = "opaque",
+    .m_doc      = NULL,
+    .m_size     = 0,
+    .m_methods  = mod_methods,
+    .m_slots    = mod_slots,
     .m_traverse = NULL,
-    .m_clear = NULL,
-    .m_free = NULL,
+    .m_clear    = NULL,
+    .m_free     = NULL,
 };
 
 PyObject* PyInit_opaque(void);
