@@ -23,15 +23,14 @@
     return @"objc-cls";
 }
 
-
-+(id)invokeInst:(OC_NSUnavailable*)inst
++ (id)invokeInst:(OC_NSUnavailable*)inst
 {
-   return [inst instmeth1];
+    return [inst instmeth1];
 }
 
-+(id)invokeCls
++ (id)invokeCls
 {
-   return [self clsmeth1];
+    return [self clsmeth1];
 }
 
 @end
@@ -48,23 +47,25 @@
 }
 @end
 
-
 static PyMethodDef mod_methods[] = {{0, 0, 0, 0}};
 
-static int mod_exec_module(PyObject* m)
+static int
+mod_exec_module(PyObject* m)
 {
     if (PyObjC_ImportAPI(m) < 0) { // LCOV_BR_EXCL_LINE
-        return -1; // LCOV_EXCL_LINE
+        return -1;                 // LCOV_EXCL_LINE
     }
 
     if (PyModule_AddObject(m, // LCOV_EXCL_LINE
-                "OC_NSUnavailable", PyObjC_IdToPython([OC_NSUnavailable class]))
+                           "OC_NSUnavailable",
+                           PyObjC_IdToPython([OC_NSUnavailable class]))
         < 0) {
         return -1; // LCOV_EXCL_LINE
     }
 
     if (PyModule_AddObject(m, // LCOV_EXCL_LINE
-                "OC_NSUnavailableChild", PyObjC_IdToPython([OC_NSUnavailableChild class]))
+                           "OC_NSUnavailableChild",
+                           PyObjC_IdToPython([OC_NSUnavailableChild class]))
         < 0) {
         return -1; // LCOV_EXCL_LINE
     }
@@ -72,42 +73,37 @@ static int mod_exec_module(PyObject* m)
 }
 
 static struct PyModuleDef_Slot mod_slots[] = {
-    {
-        .slot = Py_mod_exec,
-        .value = (void*)mod_exec_module
-    },
+    {.slot = Py_mod_exec, .value = (void*)mod_exec_module},
 #if PY_VERSION_HEX >= 0x030c0000
     {
         /* This extension does not use the CPython API other than initializing
          * the module, hence is safe with subinterpreters and per-interpreter
          * GILs
          */
-        .slot = Py_mod_multiple_interpreters,
+        .slot  = Py_mod_multiple_interpreters,
         .value = Py_MOD_PER_INTERPRETER_GIL_SUPPORTED,
     },
 #endif
 #if PY_VERSION_HEX >= 0x030d0000
     {
-        .slot = Py_mod_gil,
+        .slot  = Py_mod_gil,
         .value = Py_MOD_GIL_NOT_USED,
     },
 #endif
-    {  /* Sentinel */
-        .slot = 0,
-        .value = 0
-    }
-};
+    {/* Sentinel */
+     .slot  = 0,
+     .value = 0}};
 
 static struct PyModuleDef mod_module = {
-    .m_base = PyModuleDef_HEAD_INIT,
-    .m_name = "unavailable",
-    .m_doc = NULL,
-    .m_size = 0,
-    .m_methods = mod_methods,
-    .m_slots = mod_slots,
+    .m_base     = PyModuleDef_HEAD_INIT,
+    .m_name     = "unavailable",
+    .m_doc      = NULL,
+    .m_size     = 0,
+    .m_methods  = mod_methods,
+    .m_slots    = mod_slots,
     .m_traverse = NULL,
-    .m_clear = NULL,
-    .m_free = NULL,
+    .m_clear    = NULL,
+    .m_free     = NULL,
 };
 
 PyObject* PyInit_unavailable(void);
