@@ -4,6 +4,11 @@ from PyObjCTools.TestSupport import TestCase
 NSObject = objc.lookUpClass("NSObject")
 
 
+class NotBool:
+    def __bool__(self):
+        raise RuntimeError("not bool")
+
+
 class TestFinal(TestCase):
     def test_default_nonfinal(self):
         self.assertFalse(NSObject.__objc_final__)
@@ -29,7 +34,17 @@ class TestFinal(TestCase):
 
         self.assertTrue(NonFinalClass.__objc_final__)
 
+        class NoCompare:
+            def __bool__(self):
+                raise RuntimeError("no compare")
+
+        with self.assertRaises(RuntimeError):
+            NonFinalClass.__objc_final__ = NoCompare()
+
         with self.assertRaisesRegex(
             TypeError, "Cannot delete __objc_final__ attribute"
         ):
             del NonFinalClass.__objc_final__
+
+        with self.assertRaisesRegex(RuntimeError, "not bool"):
+            NonFinalClass.__objc_final__ = NotBool()
