@@ -1,6 +1,6 @@
 import objc
 import warnings
-from PyObjCTools.TestSupport import TestCase
+from PyObjCTools.TestSupport import TestCase, pyobjc_options
 from .fnd import NSMutableArray
 from .objectint import OC_ObjectInt
 from .test_blocks import OCTestBlock
@@ -9,6 +9,11 @@ import sys
 import io
 
 
+class NoBool:
+    def __bool__(self):
+        raise RuntimeError("no bool")
+
+
 class TestOptions(TestCase):
     def test_verbose(self):
         orig = objc.options.verbose
@@ -20,6 +25,9 @@ class TestOptions(TestCase):
             objc.options.verbose = ""
             self.assertIs(objc.options.verbose, False)
 
+            with self.assertRaisesRegex(RuntimeError, "no bool"):
+                objc.options.verbose = NoBool()
+
             with self.assertRaisesRegex(
                 AttributeError, "Cannot delete option 'verbose'"
             ):
@@ -64,6 +72,9 @@ class TestOptions(TestCase):
             objc.options.use_kvo = ""
             self.assertIs(objc.options.use_kvo, False)
 
+            with self.assertRaisesRegex(RuntimeError, "no bool"):
+                objc.options.use_kvo = NoBool()
+
             with self.assertRaisesRegex(
                 AttributeError, "Cannot delete option 'use_kvo'"
             ):
@@ -79,6 +90,9 @@ class TestOptions(TestCase):
             objc.options.unknown_pointer_raises = 1
             self.assertIs(objc.options.unknown_pointer_raises, True)
 
+            with self.assertRaisesRegex(RuntimeError, "no bool"):
+                objc.options.unknown_pointer_raises = NoBool()
+
             objc.options.unknown_pointer_raises = ""
             self.assertIs(objc.options.unknown_pointer_raises, False)
 
@@ -100,6 +114,9 @@ class TestOptions(TestCase):
             objc.options.structs_indexable = ""
             self.assertIs(objc.options.structs_indexable, False)
 
+            with self.assertRaisesRegex(RuntimeError, "no bool"):
+                objc.options.structs_indexable = NoBool()
+
             with self.assertRaisesRegex(
                 AttributeError, "Cannot delete option 'structs_indexable'"
             ):
@@ -118,6 +135,9 @@ class TestOptions(TestCase):
             objc.options.structs_writable = ""
             self.assertIs(objc.options.structs_writable, False)
 
+            with self.assertRaisesRegex(RuntimeError, "no bool"):
+                objc.options.structs_writable = NoBool()
+
             with self.assertRaisesRegex(
                 AttributeError, "Cannot delete option 'structs_writable'"
             ):
@@ -581,6 +601,33 @@ class TestOptions(TestCase):
             objc.options._date_types = orig_date_types
             objc.options._path_types = orig_path_types
 
+    def test_proxy_with_invalid_types(self):
+
+        orig_mapping_types = objc.options._mapping_types
+        orig_sequence_types = objc.options._sequence_types
+        orig_set_types = objc.options._set_types
+        orig_date_types = objc.options._date_types
+        orig_path_types = objc.options._path_types
+
+        for nm in ("_mapping_types", "_sequence_types"):
+            try:
+                setattr(objc.options, nm, 42)
+
+                with objc.autorelease_pool():
+                    a = NSMutableArray.alloc().init()
+
+                    with self.assertRaisesRegex(TypeError, "isinstance"):
+                        a.addObject_(object())
+
+                    del a
+
+            finally:
+                objc.options._mapping_types = orig_mapping_types
+                objc.options._sequence_types = orig_sequence_types
+                objc.options._set_types = orig_set_types
+                objc.options._date_types = orig_date_types
+                objc.options._path_types = orig_path_types
+
     def test_date_proxy_without_options(self):
         orig_date = objc.options._datetime_date_type
         orig_datetime = objc.options._datetime_datetime_type
@@ -613,3 +660,13 @@ class TestOptions(TestCase):
             objc.options._datetime_date_type = orig_date
             objc.options._datetime_datetime_type = orig_datetime
             objc.options._date_types = orig_date_types
+
+    def test_c_void_p(self):
+        with pyobjc_options(_c_void_p=42):
+            self.assertEqual(objc.options._c_void_p, 42)
+
+            with self.assertRaisesRegex(TypeError, "'int' object is not callable"):
+                objc.lookUpClass("NSObject").alloc().init().__c_void_p__()
+
+        with self.assertRaisesRegex(AttributeError, "Cannot delete option '_c_void_p'"):
+            del objc.options._c_void_p
